@@ -39,9 +39,7 @@ static int themousefd=-1;
 
 /* globals used by my painting stuff */  
 static uchar *offscreen=NULL, *ptorigin;
-static int enablebackground;
 static int ofscx1, ofscy1, ofscx2, ofscy2;
-static int thegraphmode, oldgraphmode;
 static int fontw, fonth, fonts;
 
 /* Function prototypes for font-scaling */
@@ -171,7 +169,7 @@ static void catcher(int v){
 
 /* the console switching of course is another quite   */
 /* rather tricky issue. for the scope of dvifb there  */
-/* is only one the routine "myupdate" actually drawing*/
+/* is only the routine "myupdate" actually drawing    */
 /* in the framebuffer ... giving me a chance          */
 
 static volatile int updateinprogress=0;
@@ -260,27 +258,6 @@ void setpalette(void) {
   int i;
   long gl;
 
-  COLORS_PER_GREY   =16;      /* should be 2^BITS_PER_GREY */
-
-  WHITECOL          =0;
-  BLACKCOL          =(COLORS_PER_GREY-1);
-  BORDERCOL         =COLORS_PER_GREY;
-  TEXTCOL           =COLORS_PER_GREY+1;
-  TEXTBACKCOL       =COLORS_PER_GREY+2;
-  FRAMECOL          =COLORS_PER_GREY+3;
-  TFMCOL            =COLORS_PER_GREY+4;
-  RECTCOL           =COLORS_PER_GREY+5;
-
-  BACKCOLS          =COLORS_PER_GREY+16; /* start at least transparent */
-  MARKSCOL          =COLORS_PER_GREY+17;
-  MARKHCOL          =COLORS_PER_GREY+18;
-  FOUNDCOL          =COLORS_PER_GREY+19;
-  HREFCOL           =COLORS_PER_GREY+20;
-  MARKDCOL          =COLORS_PER_GREY+21;
-  MIXEDCOL          =COLORS_PER_GREY+22; /* mixed all                  */
-
-  NUMBER_OF_COLORS  =COLORS_PER_GREY+23; /*number of colors */
-
   for(i=0;i<COLORS_PER_GREY;i++) {
     gl=(i==0) ? 0: 0xffff * exp(GAMMA*log(i/(float) (COLORS_PER_GREY-1)));
     fbsetpalettecolor(COLORS_PER_GREY-1-i,gl,gl,gl);
@@ -306,7 +283,6 @@ void vgaopen(void) {
   char vtdevice[50];
   char* str;
   int  ttyfd, vtno;
-  uchar o;
   struct vt_stat ttystat;
   struct vt_mode vtmode;
 
@@ -328,9 +304,9 @@ void vgaopen(void) {
   /* Why?                                                 */
   pfprot("f");
   str=getenv("FRAMEBUFFER");
-  if(str==NULL) str=THEFBDEV;
+  if(str==NULL) str=THEFBDEV;/* is this a security problem? */
   pfprot("(%s)",str);
-  thefbfd=open(str,O_RDWR); /* want write-only here */
+  thefbfd=open(str,O_RDWR);  /* want write-only here */
   if(thefbfd==-1) 
     vgaerror("cannot open framebuffer device");
   if(0!=ioctl(thefbfd,FBIOGET_FSCREENINFO, &fixinfo))
@@ -362,6 +338,18 @@ void vgaopen(void) {
   pfprot("(set euid %d uid %d)",geteuid(),getuid());
 #endif
 
+  /* .. some basic tests, copied from below: under certain */
+  /* circumstances it is wise to bail out right here       */
+  if(!isatty(STDIN_FILENO))
+    vgaerror("stdin not a terminal");
+  ttyfd=open("/dev/tty", O_RDWR);
+  if(ttyfd < 0) 
+    vgaerror("cannot open /dev/tty");
+  if(ioctl(ttyfd, VT_GETSTATE, &ttystat)!=0)
+    vgaerror("cannot get state of vt");
+  close(ttyfd);
+
+
   /* save framebuffers palette */
   pfprot("c");
   origpalette.start=0;
@@ -370,20 +358,25 @@ void vgaopen(void) {
   origpalette.green=origgreens;
   origpalette.blue=origblues;
   origpalette.transp=origtrans;
-  if(0!=ioctl(thefbfd,FBIOGETCMAP, &origpalette))
+  if(0!=ioctl(thefbfd,FBIOGETCMAP, &origpalette)){
+    origpalette.len=0;
     vgaerror("\nerror: writefb: readpalette\n");
+  }
 
   /* accocaletmviews offscreenbuffer */
   allocmem(&offscreen,thefblen);
 
   /* open mouse deveice */
 #ifdef HASMOUSE
+  {
+  uchar o;
   pfprot("i");
   pfprot("(%s)",THEMOUSEDEV);
   themousefd=open(THEMOUSEDEV,O_RDONLY | O_NONBLOCK);
   if(themousefd==-1)
     vgaerror("could not open mouse device");
   while(1==read(themousefd, &o, 1)); 
+  }
 #endif  
 
   /* install signal handlers for vt-switching */
@@ -421,7 +414,6 @@ void vgaopen(void) {
   noblotermattr.c_cc[VMIN] = 0;
   noblotermattr.c_cc[VTIME] = 0;
   tcsetattr(STDIN_FILENO,TCSAFLUSH, &noblotermattr);
-
   pfprot("\n");
 }
 
@@ -540,7 +532,6 @@ uchar vgagetchar(int mode) {
   */
   uchar input,next1,next2,next3;
   uchar com=KEYNOP;
-  struct termios tattr;
 
   if(mode2char>=0){
      com=mode2char;  
@@ -593,8 +584,10 @@ uchar vgagetchar(int mode) {
 #define MAXMOUSEBUF 100 
 #define PACKLEN 5
 
+#ifdef HASMOUSE
 static unsigned char mousebuf[MAXMOUSEBUF];
 static int nmousebuf=0;
+#endif
 static int omx, omy;
 
 void vgasetmouse(int x, int y) {
@@ -603,12 +596,9 @@ void vgasetmouse(int x, int y) {
 }  
 
 void vgagetmouse(int *x, int *y, int *left, int* right) {
-  int button,dx,dy; 
-  uchar o;
-  int p,rb;
-
-  dx=0; dy=0; button=0; 
+  int button=0,dx=0,dy=0; 
 #ifdef HASMOUSE
+  int p,rb;
   if(donotupdate==0){ /* only care about the mouse as long as the vt is active */
     while(1){ /* fill mousebuf */
       rb=read(themousefd, mousebuf+nmousebuf, MAXMOUSEBUF-nmousebuf);
@@ -638,7 +628,6 @@ void vgagetmouse(int *x, int *y, int *left, int* right) {
     } /*end: fill mousebuf */
   } /* donotupdate */
 
-
   /* cheap acceleration. turn it of by MOUSESPEED=1 */
   if(abs(dx) > MOUSESPEED) dx*=MOUSESPEED;
   if(abs(dy) > MOUSESPEED) dy*=MOUSESPEED;
@@ -660,6 +649,7 @@ void vgascreen(int son) {
    now the pixel copy stuff. 
    destination is allways the offscreen context. 
    provide debugging makros to potential segfaults.
+*/
 
 /* #define DEBUGPIXEL */
 
@@ -707,10 +697,17 @@ void mysetclipof(void) {
    ofscy2=truevgaydim-1; 
 }
 
+
+/* dimm colors for color special */
+int mydimm(int color, int dimm) {
+  return(color>>dimm);
+}
+
+
 /*****************************************************************/
 /* actually draw something                                       */
 
-void mycopybitsbw(int tx, int ty, int sw, int sh, void* src) {
+void mycopybitsbw(int tx, int ty, int sw, int sh, void* src, int c) {
 /* this is with self made clipping. no good  ? */
 /* but it will do for all kind of BMUNIT       */
  
@@ -720,6 +717,7 @@ void mycopybitsbw(int tx, int ty, int sw, int sh, void* src) {
   register BMUNIT data, mask;
   short sbmu_wide;
   char *ydest, *xdest;
+  char blackc; 
 
   /*fprintf(prot,"(vgacopybitmap1 : tx %d ty %d sw %d sh %d, ...\n",
        tx,ty,sw, sh); */                             
@@ -736,6 +734,7 @@ void mycopybitsbw(int tx, int ty, int sw, int sh, void* src) {
   /* fprintf(prot,"clipped: tx %d ty %d mi %d si %d mj %d sj %d \n",
      tx,ty,mini,supi,minj,supj); */
   
+  blackc=(*vgadimm)(BLACKCOL,c);
   sbmu_wide= ROUNDUP(sw,BITS_PER_BMUNIT);
   skip= minj & (BITS_PER_BMUNIT-1);
   sx= minj >> BITS_LOG2;
@@ -754,7 +753,7 @@ void mycopybitsbw(int tx, int ty, int sw, int sh, void* src) {
         mask=premask;
         data= *(++sbmu);
       }
-      if(data & mask) *xdest=BLACKCOL;
+      if(data & mask) *xdest=  blackc;
       mask >>= 1;
       xdest++;
     }
@@ -766,7 +765,7 @@ void mycopybitsbw(int tx, int ty, int sw, int sh, void* src) {
 
 
 
-void mycopybitsgs(int tx, int ty, int sw, int sh, void* src) { 
+void mycopybitsgs(int tx, int ty, int sw, int sh, void* src, int c) { 
 /* this is with self made clipping. no good  ? */
 /* but it will do for all kind of BMUNIT       */
 /* compatible to gl_putbox                     */
@@ -778,6 +777,7 @@ void mycopybitsgs(int tx, int ty, int sw, int sh, void* src) {
   short sbmu_wide;
   int rs, firstrs;
   char *ydest, *xdest;
+  char paintc, sourcec;
 
   mini=minj=0;
   if(ty<ofscy1) {mini= ofscy1-ty; ty=ofscy1;} 
@@ -814,7 +814,17 @@ void mycopybitsgs(int tx, int ty, int sw, int sh, void* src) {
         data= *(++sbmu); 
       }
       /* pfprot("- ptr 0x%x data %d -",xdest,((data &mask)>>rs));  */
-      (*xdest) |= ((data & mask) >> rs); 
+#ifndef LETSTRYCOLOR
+      (*xdest) |= ((data & mask) >> rs); /* sleezy but fast .. (rs+c) */
+#else
+      if((paintc=(data & mask) >> (rs+c))){
+        if((sourcec=(*xdest) & (COLORS_PER_GREY-1))){
+          if((paintc+=sourcec)>COLORS_PER_GREY-1) paintc=COLORS_PER_GREY-1;
+          (*xdest) &= ~(COLORS_PER_GREY-1);
+	}
+        (*xdest) |=paintc;
+      }
+#endif
       mask >>= GREYSCALE;
       rs-=GREYSCALE;
       xdest++;
@@ -834,7 +844,7 @@ void mycopybits88(int tx, int ty, int sw, int sh, char* src) {
 /* copy bytes to bytes                         */
 /* compatible to gl_putbox                     */
 
-  int j,i,supi,supj,mini,minj,skip;
+  int j,i,supi,supj,mini,minj;
   char *srow, *sbmu;
   char *ydest, *xdest;
 
@@ -871,6 +881,7 @@ void mycopybits88(int tx, int ty, int sw, int sh, char* src) {
 void myfillboxor(int tx, int ty, int w, int h, int c) {
  
   char *ydest, *xdest;
+  char sourcec, paintc;
   int i;
 
   /* pfprot("(vgafillboxor : tx %d ty %d sw %d sh %d, ...\n",
@@ -887,12 +898,22 @@ void myfillboxor(int tx, int ty, int w, int h, int c) {
   ydest=ptorigin+ty*PTDELTAV+tx;
   /* pfprot("clipped or box: tx %d ty %d w %d h %d   \n",
      tx,ty,w,h); */ 
-
+  paintc=0;
   for (;h>0;h--) {
     xdest=ydest; 
     for (i=w;i>0;i--) {
        CPT(xdest,"rector")                
-       (*(xdest))|=c;
+#ifndef LETSTRYCOLOR
+       (*xdest)|=c; /* sleezy but fast    */
+#else
+       if((sourcec=(*xdest) & (COLORS_PER_GREY-1))){
+         if((paintc =c+sourcec)>COLORS_PER_GREY-1) paintc=COLORS_PER_GREY-1;
+         (*xdest) &= ~(COLORS_PER_GREY-1);
+         (*xdest) |=paintc;
+       } else {
+         (*xdest) |=c;
+       }
+#endif
        xdest++;
     }
     ydest+=PTDELTAV;
@@ -927,8 +948,8 @@ void myfillboxbg(int tx, int ty, int w, int h, int c) {
     for (i=w;i>0;i--) {      
       CPT(xdest,"rectbg")
       xdc=*xdest; 
-      if(xdc) {      
-      /*if(xdc>c) *xdest=c;                       /* transparent modus */     
+      if(xdc){      
+      /*if(xdc>c) *xdest=c;  */                   /* transparent modus */     
         if(xdc>BACKCOLS && xdc!= c) *xdest=MIXEDCOL;   /* mixing modus */  
       } else *xdest=c;
       xdest++;
@@ -943,7 +964,6 @@ void myfillbox(int tx, int ty, int w, int h, int c) {
   char *ydest;
   int i;
   register char *xdest;
-  register char xdc;
   if(ty<ofscy1) {h-=ofscy1-ty;  ty=ofscy1;} 
   if(tx<ofscx1) {w-=ofscx1-tx; tx=ofscx1;} 
   if(ty+h>ofscy2+1) h=ofscy2+1-ty;
@@ -1001,11 +1021,10 @@ void vgaupdatestatus(void) {
 
 
 void vgadrawstatus(char chr, int line, int pos) {
-  int i; 
   if(line>=vgastatuslines || line <0) return;
   if(pos>=vgastatuslen || pos <0) return;
   mysetclipof();
-  /* chr=(line&0x0f)*16 + (pos&0x0f);  /* test charset */
+  /* chr=(line&0x0f)*16 + (pos&0x0f); *//* test charset */
   mycopybits88(pos*fontw+1, vgaydim+(line+1)* vgastatushight-fonth, 
         fontw, fonth, expandedfont + (unsigned char) chr *fonth*fontw);
   mysetclip(0,0,vgaxdim-1,vgaydim-1); 
@@ -1018,8 +1037,9 @@ void (*vgasetclip)(int, int, int, int) = mysetclip;
 void (*vgadrawrect)(int x, int y, int w, int h, int c) = myfillbox; 
 void (*vgadrawrector)(int x, int y, int w, int h, int c) = myfillboxor; 
 void (*vgadrawrectbg)(int x, int y, int w, int h, int c) = myfillboxbg; 
-void (*vgacopybitmapgs)(int x, int y, int w, int h, void* src) = mycopybitsgs; 
-void (*vgacopybitmapbw)(int x, int y, int w, int h, void* src) = mycopybitsbw;
+int  (*vgadimm)(int, int) = mydimm;
+void (*vgacopybitmapgs)(int x, int y, int w, int h, void* src, int c) = mycopybitsgs; 
+void (*vgacopybitmapbw)(int x, int y, int w, int h, void* src, int c) = mycopybitsbw;
 
 
 /***************************************************************************/
@@ -1033,7 +1053,7 @@ void (*vgacopybitmapbw)(int x, int y, int w, int h, void* src) = mycopybitsbw;
 void preparefont(void) {
   uchar *src;
   uchar *dst;
-  int i,x,y,b;         
+  int i,x,y,b=0;         
 
   fonth=FONTH;
   fontw=FONTW;
