@@ -4,11 +4,6 @@
 /* distributed without any restrictions.                                 */
 
 
-/*
-   This file is modified for use with Solaris. However, it shoud go
-   with any XWindow ...
-*/
-
 #include "../src/defs.h"
              
 #include <X11/Xos.h>                      /* X header files              */ 
@@ -19,31 +14,30 @@
 
 
 /* prefered Image format */
-/* you may set up tmview for the depth of your display. 8bit and 16bit is  */
-/* tested. If you use tmview with a depth not the same as defined here, it */
-/* will become very slow. */
+/* you may set up tmview for the depth of your display. 8bit, 16bit and 24bit is  */
+/* tested. Be aware of non-i386 architectures, where a "long int" might not       */
+/* consist of 4 bytes; e.g. alpha uses 8 bytes. The 8bit version based on "uchar" */
+/* should be pretty save ... until they introduce unicode? However, if you use    */
+/* tmview with a depth not the same as defined here, it will become a bit slow.   */
 
 /* 32/24 bit per pixel */
 /*#define IUNIT unsigned long 
 #define IBYTES_PER_PIXEL 4
-#define IBITS_PER_PIXEL 32
-#define IGET_PIXEL(ptr) (*(ptr))
-#define ISET_PIXEL(ptr,c) (*(ptr) = (c))*/ 
+#define IBITS_PER_PIXEL 32 */
 /* 16 bit per pixel */
 /*#define IUNIT unsigned short 
 #define IBYTES_PER_PIXEL 2
-#define IBITS_PER_PIXEL 16
-#define IGET_PIXEL(ptr) (*(ptr))
-#define ISET_PIXEL(ptr,c) (*(ptr) = (c)) */
+#define IBITS_PER_PIXEL 16 */
 /* 8 bit per pixel */
 #define IUNIT unsigned char 
 #define IBYTES_PER_PIXEL 1
-#define IBITS_PER_PIXEL 8
+#define IBITS_PER_PIXEL 8 
+
 #define IGET_PIXEL(ptr) (*(ptr))
-#define ISET_PIXEL(ptr,c) (*(ptr) = (c)) 
+#define ISET_PIXEL(ptr,c) (*(ptr) = (c))
 
 
-/* #define DEBUGX  /* watch tmview contacting the XServer */
+/*#define DEBUGX *//* watch tmview contacting the XServer */
 
 #include "writelx.h"
 
@@ -66,6 +60,7 @@ static char* tforename;
 static char* dwhitename;
 static char* dblackname;
 static char* geometry;
+static int   geox,geoy,geow,geoh,geodx,geody,geof=0;
 
 /* globals belongimg to ma paintings */
 static Pixel palette[NUMBER_OF_COLORS]; 
@@ -82,8 +77,8 @@ void (*vgasetclip)(int, int, int, int)=NULL;
 void (*vgadrawrect)(int x, int y, int w, int h, int c)=NULL; 
 void (*vgadrawrector)(int x, int y, int w, int h, int c)=NULL; 
 void (*vgadrawrectbg)(int x, int y, int w, int h, int c)=NULL; 
-void (*vgacopybitmapgs)(int x, int y, int w, int h, void* src)=NULL;
-void (*vgacopybitmapbw)(int x, int y, int w, int h, void* src)=NULL;
+void (*vgacopybitmapgs)(int x, int y, int w, int h, void* src, int c)=NULL;
+void (*vgacopybitmapbw)(int x, int y, int w, int h, void* src, int c)=NULL;
 
 
 /* Function prototypes textdarwing */
@@ -135,11 +130,12 @@ void alloc_off(void) {
   
   if(ibytes_per_pixel != IBYTES_PER_PIXEL) {
     pfprot("\n
-warning: display: tmVIEW prefers %d-bit depth. 
-  Recompile for better performance.\n", IBYTES_PER_PIXEL*8);
+warning: display: found %d-bit depth while optimized for %d-bit.
+  Recompile for better performance.\n", offimage->depth, IBYTES_PER_PIXEL*8);
     setvar();
   } else {
-    /*pfprot("\nwritelx: using own pix-map functions");*/
+    pfverb("writelx: using built in  %d-bit pixmap functions on a %d-bit display\n",
+      IBYTES_PER_PIXEL*8,offimage->depth);
     setfix();
   }
 
@@ -160,7 +156,7 @@ warning: display: tmVIEW prefers %d-bit depth.
   } else
     pfprot("bits MSBFirst ");
   pfprot("bytes_per_line %d truevgaxdim %d ",ibytes_per_line,truevgaxdim);
-  printf("image at 0x%x, data at 0x%x\n",offimage,offscreen);
+  printf("image at %p, data at %p\n",offimage,offscreen);
 #endif
 }
 
@@ -346,44 +342,50 @@ void setcolormap(void) {
 }
 
 
+/* inverse of palette array: hm. this should be done better somehow */
+int invpalette(Pixel cpix){
+  int i;
+  if(cpix==white) return(WHITECOL);
+  if(cpix==black) return(BLACKCOL);
+  for(i=WHITECOL+1; i<NUMBER_OF_COLORS; i++)
+    if(palette[i]==cpix) return(i);
+  pfprot("(invpalette: unknown color)");
+  return(0);
+}
 
-set_sizehints (XSizeHints *hintp, int w, int h, int x, int y,char* geom)
-{
-    int geom_result;
+
+void set_sizehints (XSizeHints *hintp, int w, int h, int x, int y,char* geom){
+  int geom_result;
     
-    /* set the size hints, algorithm from xlib xbiff */
+  /* set the size hints, algorithm from xlib xbiff */
 
-    hintp->width = hintp->min_width = VGAXDIMMIN;
-    hintp->height = hintp->min_height = VGAYDIMMIN;
-    hintp->flags = PMinSize;
-    hintp->x = hintp->y = 0;
-    geom_result = NoValue;
-    if (geom != NULL) {
-        geom_result = XParseGeometry (geom, &hintp->x, &hintp->y,
+  hintp->width = hintp->min_width = VGAXDIMMIN;
+  hintp->height = hintp->min_height = VGAYDIMMIN;
+  hintp->flags = PMinSize;
+  hintp->x = hintp->y = 0;
+  geom_result = NoValue;
+  if(geom != NULL) {
+    geom_result = XParseGeometry (geom, &hintp->x, &hintp->y,
 				      (unsigned int *)&hintp->width,
 				      (unsigned int *)&hintp->height);
-	if ((geom_result & WidthValue) && (geom_result & HeightValue)) {
-	    hintp->width = MAX(hintp->width, hintp->min_width);
-	    hintp->height = MAX(hintp->height, hintp->min_height);
-	    hintp->flags |= USSize;
-	}
-	if ((geom_result & XValue) && (geom_result & YValue)) {
-	    hintp->flags += USPosition;
-	}
+    if((geom_result & WidthValue) && (geom_result & HeightValue)) {
+      hintp->width = MAX(hintp->width, hintp->min_width);
+      hintp->height = MAX(hintp->height, hintp->min_height);
+      hintp->flags |= USSize;
     }
-    if (!(hintp->flags & USSize)) {
-	hintp->width = w;
-	hintp->height= h;
-	hintp->flags |= PSize;
-    }
-    if (geom_result & XNegative) {
-	hintp->x = DisplayWidth (dpy, DefaultScreen (dpy)) + hintp->x -
-		    hintp->width;
-    }
-    if (geom_result & YNegative) {
-	hintp->y = DisplayHeight (dpy, DefaultScreen (dpy)) + hintp->y -
-		    hintp->height;
+    if((geom_result & XValue) && (geom_result & YValue)) {
+      hintp->flags += USPosition;
     }
+  }
+  if(!(hintp->flags & USSize)) {
+    hintp->width = w;
+    hintp->height= h;
+    hintp->flags |= PSize;
+  }
+  if(geom_result & XNegative) 
+    hintp->x = DisplayWidth(dpy,DefaultScreen(dpy))+hintp->x-hintp->width;
+  if(geom_result & YNegative) 
+    hintp->y = DisplayHeight(dpy,DefaultScreen(dpy))+hintp->y-hintp->height;
 }
 
 
@@ -391,21 +393,18 @@ set_sizehints (XSizeHints *hintp, int w, int h, int x, int y,char* geom)
 
 void vgaopen(void) {
   char* displayname=NULL;
-  int* depthlist;
-  int n;
+#ifdef DEBUGX
   XPixmapFormatValues* pixforlist;
+  int* depthlist;
   XVisualInfo* vislist;
   XVisualInfo  vistemp;
-  int npixforlist;
-  int i;
+  int npixforlist,i,n;
 
-  offscreen=NULL;  /* to be shure */
-
-  
-#ifdef DEBUGX
   pfprot("(vgaopen ...\n"); 
 #endif
 
+  offscreen=NULL;  /* to be shure */
+
   /* better ask option !! */    
   dpy=XOpenDisplay(displayname);
   if (!dpy) {
@@ -447,10 +446,6 @@ void vgaopen(void) {
   if(dwhitename==NULL)
     dwhitename="OldLace";
 
-  geometry=XGetDefault(dpy,"DviLX","geometry");
-  /*  if(geometry==NULL)
-    geometry="500x500"; */
-
   
 
 #ifdef DEBUGX
@@ -515,7 +510,6 @@ void vgagraph(void) {
 
   XSetWindowAttributes attr;
   XWindowAttributes gattr;
-  char* geom=NULL; 
   XSizeHints hints;
   XGCValues values;
   unsigned long valuemask, attrmask;
@@ -525,9 +519,13 @@ void vgagraph(void) {
   pfprot("(vgagraph ... \n)");
 #endif	 
     
-  vgaxdim = MAX(VGAXDIMMIN,vgaxdim);  
+  /* now that geometry: too many sources? */  
+  geometry=XGetDefault(dpy,"DviLX","geometry"); /* A. from resources */
+  if(cmlgeometry!=NULL)
+    stralloccpy(&geometry,cmlgeometry);         /* B. -geometry option */
+  vgaxdim = MAX(VGAXDIMMIN,vgaxdim);            /* C. -d option */
   vgaydim = MAX(VGAYDIMMIN,vgaydim);
-  set_sizehints (&hints, vgaxdim, vgaydim, 10,10,geometry);
+  set_sizehints(&hints, vgaxdim, vgaydim, 10,10,geometry); /* merge them all */
  
 
   /* setup window attributes */
@@ -539,7 +537,7 @@ void vgagraph(void) {
    
 
   attr.background_pixel = palette[0];
-  attr.backing_store=NotUseful;
+  attr.backing_store=WhenMapped;
   attrmask = CWBackPixel | CWEventMask | CWBackingStore;
   dviwin = XCreateWindow (dpy, RootWindow(dpy, screen), hints.x, hints.y,
 			   hints.width, hints.height,5, 
@@ -561,7 +559,7 @@ void vgagraph(void) {
 
   vgaxdim=gattr.width;
   vgaydim=gattr.height;
-  truevgaxdim=(vgaxdim | 3) +1;
+  truevgaxdim=((vgaxdim-1) | 3) +1;
   truevgaydim=vgaydim;
 
   values.function=GXcopy;
@@ -595,7 +593,13 @@ void vgagraph(void) {
 /***************************************************************************/
 
 
-void mycopybitsbw(int tx, int ty, int sw, int sh, void* src) {
+/* dimm colors for color special */
+int mydimm(int color, int dimm) {
+  return(color>>dimm);
+}
+
+
+void mycopybitsbw(int tx, int ty, int sw, int sh, void* src, int c) {
 /* this is with self made clipping. no good  ? */
 /* but it will do for all kind of BMUNIT       */
  
@@ -604,6 +608,7 @@ void mycopybitsbw(int tx, int ty, int sw, int sh, void* src) {
   BMUNIT premask, firstpremask;
   register BMUNIT data, mask;
   short sbmu_wide;
+  Pixel blackc;
 
 
   /*fprintf(prot,"(vgacopybitmap1 : tx %d ty %d sw %d sh %d, ...\n",
@@ -621,8 +626,9 @@ void mycopybitsbw(int tx, int ty, int sw, int sh, void* src) {
   sbmu_wide= ROUNDUP(sw,BITS_PER_BMUNIT);
   skip= minj & (BITS_PER_BMUNIT-1);
   sx= minj >> BITS_LOG2;
-  premask = 1 << (BITS_PER_BMUNIT-1);
+  premask = ((BMUNIT)1) << (BITS_PER_BMUNIT-1);
   firstpremask = premask >> skip;
+  blackc=palette[(BLACKCOL)>>c];
 
   supj=supj+tx-minj;
   supi=supi+ty-mini;
@@ -633,7 +639,7 @@ void mycopybitsbw(int tx, int ty, int sw, int sh, void* src) {
     sbmu=srow;
     data=*sbmu;
     for (j = tx;j<supj;j++) {       
-      if(data & mask) XPutPixel(offimage,j,i,black);
+      if(data & mask) XPutPixel(offimage,j,i,blackc);
       mask >>= 1;
       if(!mask) {
         mask=premask;
@@ -652,7 +658,7 @@ void mycopybitsbw(int tx, int ty, int sw, int sh, void* src) {
 
 
 
-void mycopybitsgs(int tx, int ty, int sw, int sh, void* src) { 
+void mycopybitsgs(int tx, int ty, int sw, int sh, void* src, int c) { 
 /* this is with self made clipping. no good  ? */
 /* but it will do for all kind of BMUNIT       */
 /* compatible to gl_putbox                     */
@@ -663,6 +669,7 @@ void mycopybitsgs(int tx, int ty, int sw, int sh, void* src) {
   register BMUNIT data, mask;
   short sbmu_wide;
   int rs, firstrs;
+  uchar paintc, sourcec;
 
   /* fprintf(prot,"(vgacopybitmap8 : tx %d ty %d sw %d sh %d, ...\n",
        tx,ty,sw, sh);                             
@@ -678,11 +685,12 @@ void mycopybitsgs(int tx, int ty, int sw, int sh, void* src) {
      return;
   }
 
-  
+    
+  paintc=0;
   sbmu_wide= ROUNDUP(sw << GREYSCALE_LOG2,BITS_PER_BMUNIT);
   skip= minj & ((BITS_PER_BMUNIT>>GREYSCALE_LOG2)-1);
   sx= minj >> (BITS_LOG2-GREYSCALE_LOG2);
-  premask = ((1<<GREYSCALE)-1) << (BITS_PER_BMUNIT-GREYSCALE);
+  premask = ((((BMUNIT)1)<<GREYSCALE)-1) << (BITS_PER_BMUNIT-GREYSCALE);
   firstpremask = premask >> (skip<< GREYSCALE_LOG2);
   firstrs = BITS_PER_BMUNIT-GREYSCALE - skip*GREYSCALE;
 
@@ -696,8 +704,20 @@ void mycopybitsgs(int tx, int ty, int sw, int sh, void* src) {
     sbmu=srow;
     data=*sbmu;
     for (j = tx;j<supj;j++) {
-      if(XGetPixel(offimage,j,i)==white) 
-         XPutPixel(offimage,j,i,palette[((data & mask) >> rs)]);
+#ifndef LETSTRYCOLOR      
+      if((paintc=((data & mask) >> (rs+c))))
+        if(XGetPixel(offimage,j,i)==white)
+          XPutPixel(offimage,j,i,palette[paintc]);
+#else
+      if((paintc=((data & mask) >> (rs+c)))){
+        if((sourcec=invpalette(XGetPixel(offimage,j,i)))){
+          if((paintc+=sourcec & (COLORS_PER_GREY-1))>COLORS_PER_GREY-1) 
+             paintc=COLORS_PER_GREY-1;
+          paintc|=sourcec & ~(COLORS_PER_GREY-1);
+	}
+        XPutPixel(offimage,j,i,palette[paintc]);
+      }
+#endif
       mask >>= GREYSCALE;
       rs-=GREYSCALE;
       if(!mask) {
@@ -752,6 +772,7 @@ void myfillboxor(int tx, int ty, int w, int h, int c) {
  
   int i,j,supj,supi;
   Pixel cpix;
+  uchar sourcec, paintc;
 
   /* fprintf(prot,"(vgafillboxor : tx %d ty %d sw %d sh %d, ...\n",
        tx,ty,sw, sh); */                             
@@ -759,8 +780,8 @@ void myfillboxor(int tx, int ty, int w, int h, int c) {
   if(tx<ofscx1) {w-=ofscx1-tx; tx=ofscx1;} 
   if(ty+h>ofscy2+1) h=ofscy2+1-ty;
   if(tx+w>ofscx2+1) w=ofscx2+1-tx;
-  if(w <= 0 || h<= 0) {
-     /*fprintf(prot,"clipped all away. no drawings)\n"); */
+  if(w <= 0 || h<= 0 || c==0) {
+     /*fprintf(prot,"clipped all away or white: no drawings)\n"); */
      return;
   }
  /* fprintf(prot,"clipped or box: tx %d ty %d w %d h %d   \n",
@@ -774,8 +795,19 @@ void myfillboxor(int tx, int ty, int w, int h, int c) {
  
   for (i=ty;i<supi;i++) 
     for (j=tx;j<supj;j++) 
-      if(XGetPixel(offimage,j,i)==white) 
-         XPutPixel(offimage,j,i,cpix);
+#ifndef LETSTRYCOLOR      
+      if(XGetPixel(offimage,j,i)==white)
+        XPutPixel(offimage,j,i,cpix);
+#else
+      if((sourcec=invpalette(XGetPixel(offimage,j,i)))){
+        if((paintc=c+(sourcec & (COLORS_PER_GREY-1)))>COLORS_PER_GREY-1) 
+           paintc=COLORS_PER_GREY-1;
+        paintc|=sourcec & ~(COLORS_PER_GREY-1);
+        XPutPixel(offimage,j,i,palette[paintc]);
+      } else {
+        XPutPixel(offimage,j,i,cpix);
+      }
+#endif
   if(directscreen) {
     XPutImage(dpy,dviwin,imagecopygc,offimage,tx,ty,tx,ty,w,h); 
   /* XFlush(dpy); */ 
@@ -822,7 +854,7 @@ void myfillboxbg(int tx, int ty, int w, int h, int c) {
 }
 
 
-void mycopybitsbwfix(int tx, int ty, int sw, int sh, void* src) {
+void mycopybitsbwfix(int tx, int ty, int sw, int sh, void* src, int c) {
 /* this is with self made clipping. no good  ? */
 /* but it will do for all kind of BMUNIT       */
  
@@ -832,6 +864,7 @@ void mycopybitsbwfix(int tx, int ty, int sw, int sh, void* src) {
   register BMUNIT data, mask;
   short sbmu_wide;
   IUNIT *ydest, *xdest;
+  Pixel blackc;
 
   /*fprintf(prot,"(vgacopybitmap1 : tx %d ty %d sw %d sh %d, ...\n",
        tx,ty,sw, sh); */                             
@@ -850,10 +883,11 @@ void mycopybitsbwfix(int tx, int ty, int sw, int sh, void* src) {
   /* fprintf(prot,"clipped: tx %d ty %d mi %d si %d mj %d sj %d \n",
      tx,ty,mini,supi,minj,supj); */
 
+  blackc=palette[(BLACKCOL)>>c];
   sbmu_wide= ROUNDUP(sw,BITS_PER_BMUNIT);
   skip= minj & (BITS_PER_BMUNIT-1);
   sx= minj >> BITS_LOG2;
-  premask = 1 << (BITS_PER_BMUNIT-1);
+  premask = ((BMUNIT)1) << (BITS_PER_BMUNIT-1);
   firstpremask = premask >> skip;
 
   ydest=((IUNIT*)(offscreen+ty*ibytes_per_line))+tx;  
@@ -864,7 +898,7 @@ void mycopybitsbwfix(int tx, int ty, int sw, int sh, void* src) {
     sbmu=srow;
     data=*sbmu;
     for (j = minj;j<supj;j++) {       
-      if(data & mask) ISET_PIXEL(xdest,black);
+      if(data & mask) ISET_PIXEL(xdest,blackc);
       mask >>= 1;
       xdest++;
       if(!mask) {
@@ -885,7 +919,7 @@ void mycopybitsbwfix(int tx, int ty, int sw, int sh, void* src) {
 
 
 
-void mycopybitsgsfix(int tx, int ty, int sw, int sh, void* src) { 
+void mycopybitsgsfix(int tx, int ty, int sw, int sh, void* src, int c) { 
 /* this is with self made clipping. no good  ? */
 /* but it will do for all kind of BMUNIT       */
 /* compatible to gl_putbox                     */
@@ -897,6 +931,7 @@ void mycopybitsgsfix(int tx, int ty, int sw, int sh, void* src) {
   short sbmu_wide;
   int rs, firstrs, w,h;
   IUNIT *ydest, *xdest;
+  uchar paintc, sourcec;
 
   /*printf("(vgacopybitmap8 : src 0x%x tx %d ty %d sw %d sh %d, ...\n",
        src,tx,ty,sw, sh);                             
@@ -921,9 +956,10 @@ void mycopybitsgsfix(int tx, int ty, int sw, int sh, void* src) {
   sbmu_wide= ROUNDUP(sw << GREYSCALE_LOG2,BITS_PER_BMUNIT);
   skip= minj & ((BITS_PER_BMUNIT>>GREYSCALE_LOG2)-1);
   sx= minj >> (BITS_LOG2-GREYSCALE_LOG2);
-  premask = ((1<<GREYSCALE)-1) << (BITS_PER_BMUNIT-GREYSCALE);
+  premask = ((((BMUNIT)1)<<GREYSCALE)-1) << (BITS_PER_BMUNIT-GREYSCALE);
   firstpremask = premask >> (skip<< GREYSCALE_LOG2);
   firstrs = BITS_PER_BMUNIT-GREYSCALE - skip*GREYSCALE;
+  sourcec=0;
 
   ydest=((IUNIT*)(offscreen+ty*ibytes_per_line))+tx;
   srow=((BMUNIT*)src)+mini*sbmu_wide+sx;
@@ -934,8 +970,21 @@ void mycopybitsgsfix(int tx, int ty, int sw, int sh, void* src) {
     sbmu=srow;
     data=*sbmu;
     for (j = minj;j<supj;j++) {
-      if(IGET_PIXEL(xdest)==white) 
-         ISET_PIXEL(xdest,palette[((data & mask) >> rs)]);
+#ifndef LETSTRYCOLOR       
+      if((paintc=((data & mask) >> (rs+c)))) 
+        if(IGET_PIXEL(xdest)==white)
+          ISET_PIXEL(xdest,palette[paintc]);
+#else
+      if((paintc=((data & mask) >> (rs+c)))){ 
+        if(IGET_PIXEL(xdest)!=white){
+          sourcec=invpalette(IGET_PIXEL(xdest));
+          if((paintc+=sourcec & (COLORS_PER_GREY-1))>COLORS_PER_GREY-1) 
+             paintc=COLORS_PER_GREY-1;
+          paintc|=sourcec & ~(COLORS_PER_GREY-1);
+   	}
+        ISET_PIXEL(xdest,palette[paintc]);
+      }
+#endif
       mask >>= GREYSCALE;
       rs-=GREYSCALE;
       xdest++;
@@ -998,6 +1047,7 @@ void myfillboxorfix(int tx, int ty, int w, int h, int c) {
   IUNIT *ydest, *xdest;
   int i,j;
   Pixel cpix;
+  uchar sourcec, paintc;
 
   /* fprintf(prot,"(vgafillboxor : tx %d ty %d sw %d sh %d, ...\n",
        tx,ty,sw, sh); */                             
@@ -1005,8 +1055,8 @@ void myfillboxorfix(int tx, int ty, int w, int h, int c) {
   if(tx<ofscx1) {w-=ofscx1-tx; tx=ofscx1;} 
   if(ty+h>ofscy2+1) h=ofscy2+1-ty;
   if(tx+w>ofscx2+1) w=ofscx2+1-tx;
-  if(w <= 0 || h<= 0) {
-     /*fprintf(prot,"clipped all away. no drawings)\n"); */
+  if(w <= 0 || h<= 0 || c==0) {
+     /*fprintf(prot,"clipped all away or white: no drawings)\n"); */
      return;
   }
 
@@ -1018,8 +1068,21 @@ void myfillboxorfix(int tx, int ty, int w, int h, int c) {
   for (i=h;i>0;i--) {
     xdest=ydest; 
     for (j=w;j>0;j--) {
-       if(IGET_PIXEL(xdest)==white) ISET_PIXEL(xdest,cpix);
-       xdest++;
+
+#ifndef LETSTRYCOLOR      
+      if(IGET_PIXEL(xdest)==white) 
+         ISET_PIXEL(xdest,cpix);
+#else
+      if((sourcec=invpalette(IGET_PIXEL(xdest)))){
+        if((paintc=c+(sourcec & (COLORS_PER_GREY-1)))>COLORS_PER_GREY-1) 
+           paintc=COLORS_PER_GREY-1;
+        paintc|=sourcec & ~(COLORS_PER_GREY-1);
+        ISET_PIXEL(xdest,palette[paintc]);
+      } else {
+        ISET_PIXEL(xdest,cpix);
+      }
+#endif
+      xdest++;
     }
     ((char*)ydest)+=ibytes_per_line;
   }
@@ -1125,6 +1188,7 @@ void setvar(void) {
   vgadrawrect=myfillbox; 
   vgadrawrector=myfillboxor; 
   vgadrawrectbg=myfillboxbg; 
+  vgadimm=mydimm;
   vgacopybitmapgs=mycopybitsgs;
   vgacopybitmapbw=mycopybitsbw;
 }
@@ -1135,6 +1199,7 @@ void setfix(void) {
   vgadrawrect=myfillboxfix; 
   vgadrawrector=myfillboxorfix; 
   vgadrawrectbg=myfillboxbgfix; 
+  vgadimm=mydimm;
   vgacopybitmapgs=mycopybitsgsfix;
   vgacopybitmapbw=mycopybitsbwfix;
 }
@@ -1237,7 +1302,6 @@ uchar vgagetchar(int mode) {
     mode==2: peek next key, dont block
   */
   uchar res=KEYNOP;  
-  int i;
   XEvent event;
   XEvent dummyevent;
   XKeyEvent *keyev;
@@ -1245,7 +1309,6 @@ uchar vgagetchar(int mode) {
   XMotionEvent *moev;
   XCrossingEvent *crossev;
   XButtonEvent *butev;
-  
   KeySym keysym;
   char *keynam;
   int slen;
@@ -1257,9 +1320,10 @@ uchar vgagetchar(int mode) {
      if(mode!=2) mode2char=-1;
      return(res);
   }
+  
   nev=XEventsQueued(dpy,QueuedAfterFlush);
   if(mode!=1 && nev==0) return(res);
-  XNextEvent(dpy,&event); 
+  XNextEvent(dpy,&event);
   switch (event.type) {
   case KeyPress:
     keyev = (XKeyEvent *) &event;
@@ -1294,12 +1358,34 @@ uchar vgagetchar(int mode) {
     break;
   case ConfigureNotify:
     if(offscreen==NULL) break; /* not started up jet */
-    /* pfprot("(oldsize %d %d)",vgaxdim,truevgaydim); */
     conev=(XConfigureEvent *) &event;
+    /* figure out position of our window. anyone around who knows? */
+    if(conev->send_event==1 && geof==0) {
+      geodx=geox-conev->x;
+      geody=geoy-conev->y;
+      geof=1;
+    }
+    if(conev->send_event==1 || geof==0) {
+      geox=conev->x;
+      geoy=conev->y;
+    }
+    geow=conev->width;
+    geoh=conev->height;
+    /*
+    freemem(&cmlgeometry);
+    allocmem(&cmlgeometry,100); 
+    if(-1== snprintf(cmlgeometry,99,"%dx%d+%d+%d", geow,geoh,geox+geodx,geoy+geody))
+      {pfprot("\nfatal error: gemetry .. writelx ??\n");exit(1);}
+    */
+#ifdef DEBUGX
+    pfprot("(configure notify for %ld flag %d: geometry: %dx%d+%d+%d)\n",
+         conev->window,conev->send_event,geow,geoh,geox+geodx,geoy+geody);
+#endif	 
+    pfprot("(oldsize %d %d)",vgaxdim,truevgaydim);
     newxdim = MAX(VGAXDIMMIN,conev->width);  
     newydim = MAX(VGAYDIMMIN,conev->height);
     if(newxdim==vgaxdim && newydim==truevgaydim) break;
-    truevgaxdim=(newxdim | 3) + 1;
+    truevgaxdim=((newxdim-1) | 3) + 1;
     truevgaydim=newydim;
     vgaxdim=newxdim;
     vgaydim=newydim;
@@ -1361,19 +1447,21 @@ void preparefont(void) {
   XGCValues values;
   unsigned long valuemask;
   char** fontlist;
-  int i,nfontlist;
+  int nfontlist;
 
   if(tfontname==NULL) tfontname="*-fixed-*";
   fontlist=XListFonts(dpy,tfontname,20,&nfontlist);
 
-#ifdef DEBUGX  
-  pfprot("(fontnames:\n");
-  for(i=0;i<nfontlist;i++)
-   pfprot("%s\n",fontlist[i]);
-  pfprot("\n");
-  if(nfontlist==0) vgaerror("no such font");
+#ifdef DEBUGX 
+  { int i; 
+    pfprot("(fontnames:\n");
+    for(i=0;i<nfontlist;i++)
+     pfprot("%s\n",fontlist[i]);
+    pfprot("\n");
+  }
 #endif  
 
+  if(nfontlist==0) vgaerror("no such font");
   tfontstruct=XLoadQueryFont(dpy,fontlist[0]);
   if(tfontstruct==NULL) vgaerror("Cant load font");
   
