@@ -115,7 +115,6 @@ void drawupdatepage(void) {  /* this does a total reset */
 
 
 void drawhidemark(int x, int y) {
-   int ms=MARKSIZE;
    tmpnomarks=1;
 #if CURSORSNOTONSCREEN  /* switch drirect screen off */
    vgascreen(0);
@@ -126,8 +125,8 @@ void drawhidemark(int x, int y) {
 void drawshowmark(int x, int y, int col){
    int ms=MARKSIZE; 
    /* (*vgasetclip)(0,0,vgaxdim-1,vgaydim-1); */
-   (*vgadrawrect)(x-ms,y,2*ms+1,1,BLACKCOL);
-   (*vgadrawrect)(x,y-ms,1,2*ms+1,BLACKCOL);
+   (*vgadrawrect)(x-ms,y,2*ms+1,1,vgadimm(BLACKCOL,0));
+   (*vgadrawrect)(x,y-ms,1,2*ms+1,vgadimm(BLACKCOL,0));
    (*vgadrawrectbg)(x-ms,y-ms,2*ms+1,2*ms+1,col);
    drawaddupdatelist(x-ms,y-ms,x+ms,y+ms);
 }
@@ -266,7 +265,8 @@ void drawcharbmp(drawlistdata* arg) {
                      (*arg).chr.v -theypos -thechar->vof, 
                      thechar->bmp.w,
                      thechar->bmp.h,
-                     thechar->bmp.bits);
+                     thechar->bmp.bits,
+                     (*arg).chr.c);
 }
 
 void drawcharbmp2bw(drawlistdata* arg) {  
@@ -284,7 +284,8 @@ void drawcharbmp2bw(drawlistdata* arg) {
                      (*arg).chr.v -theypos -thechar->vof2, 
                      thechar->bmp2.w,
                      thechar->bmp2.h,
-                     thechar->bmp2.bits);
+                     thechar->bmp2.bits,
+                     (*arg).chr.c);
 }
 
 void drawgscript(drawlistdata* arg){
@@ -306,7 +307,8 @@ void drawgscript(drawlistdata* arg){
                        (*arg).gscript.v -theypos, 
                        gse->bmp.w,
                        gse->bmp.h,
-                       gse->bmp.bits);
+                       gse->bmp.bits,
+                       0); /* do not dimm gscript */
   }
   if(gse->suspect==B_OK && gse->bmp.w!= gse->bmp2.w) { 
     touchlrumem(&(gse->bmp2.bits));
@@ -314,7 +316,8 @@ void drawgscript(drawlistdata* arg){
                        (*arg).gscript.v -theypos, 
                        gse->bmp2.w,
                        gse->bmp2.h,
-                       gse->bmp2.bits);
+                       gse->bmp2.bits,
+                       0); /* do not dimm gscript */
   }
   /*printf("<!!!Drawgscript DONE :-)\n"); */
 }
@@ -340,7 +343,8 @@ void drawcharbmp2gs(drawlistdata* arg) {
                      (*arg).chr.v -theypos -thechar->vof2, 
                      thechar->bmp2.w,
                      thechar->bmp2.h,
-                     thechar->bmp2.bits);
+                     thechar->bmp2.bits,
+                     (*arg).chr.c);
 #ifdef DEBUGDRAW        
   pfprot(" done)");
 #endif
@@ -621,7 +625,7 @@ void setcounterstr(void) {
    i=MAX(0,i);
    counterstr[0]=0;
    for(j=0;j<=i;j++) {
-     sprintf(bustr,"%d;",MIN(9999,MAX(-9999,cpage->count[j])));
+     sprintf(bustr,"%ld;",MIN(9999,MAX(-9999,cpage->count[j])));
      strcat(counterstr,bustr);
    }
    counterstr[strlen(counterstr)-1]=0;
@@ -635,7 +639,7 @@ int doupdate=1;
 void drawstatusmarks(void) {
   char bustr1[180], bustr2[180];
   char* refstr;
-  int bui,ol;
+  int ol;
 
   if(cpage==NULL || visfmk==NULL) return;
   if(statusforce) {
