@@ -15,8 +15,8 @@ by xdvi.
 
 #include "defs.h"
 
-/*#define DEBUGEPS  /* debug eps-file reading, rendering etc. */
-/*#define DEBUGEPSS /* parsing of special arguments */
+/*#define DEBUGEPS  *//* debug eps-file reading, rendering etc. */
+/*#define DEBUGEPSS *//* parsing of special arguments */
 
 
 /**********************************************************/
@@ -110,7 +110,6 @@ gslistelement* allocgscript(char* gsfile, char* argfile, short w, short h, float
 
 
 gslistelement* searchgscript(char* gsfile, short w, short h,float res, char* code){
-  int i;
   gslistelement* gse;
 #ifdef DEBUGEPS
   pfprot("(searchgsciptlist %s %d %d %.3f ",gsfile, w, h, res);
@@ -224,7 +223,7 @@ int checkndoEpsFile(char* specstr, long h, long v, double sconv, double svconv){
 #endif
 
 /* PART 2: Get other args ******************************/
-
+  argllx=arglly=argurx=argury=argangle=argrwi=argrhi=0;
   while(*cp != '\0') {
     while(isspace(*cp)) ++cp;
     cp_beg=cp;  
@@ -408,6 +407,7 @@ int checkndoEpsFile(char* specstr, long h, long v, double sconv, double svconv){
 
 
 /* PART 4: Add gscommand to drawlist  **************************/
+  needmem=0;
   if(doeps==DOEPS){
     needmem=((long)lheight)*((long)ROUNDUP(lwidth,BITS_PER_BMUNIT)) 
        *BYTES_PER_BMUNIT;
@@ -501,8 +501,6 @@ FILE* gs_in_write;
 
 
 int startgs(char* epsname, short width, short height, float res, char* gscode) {
-  int returncode;
-  int i;
   char gsargsize[GSARGLEN];
   char gsargres[GSARGLEN];
 
@@ -594,11 +592,10 @@ int readgs(bitmap *bmp2){
   uchar buff[GSBLOCKLEN];
   uchar *sp, *buffend;
   long bufflen;
-  uchar c;
   long  count;
   long expected;
   uchar ukey;
-  short i,jbit,jbm;
+  short jbit,jbm;
   long lshift;
   BMUNIT *dp;
   int returncode;
@@ -701,11 +698,9 @@ int readgs(bitmap *bmp2){
 
 
 void  gsloadbmp(gslistelement* gse) {
-  int i,j, gsres;
   char mess[MAXPATHSTR];
-  
-  
 #ifdef DEBUGEPS
+  int i,j;
   pfprot("(gsloadbmp: 0x%x %s %d %d %.2f ...)",
      gse,gse->gsfile,gse->bmp2.w,gse->bmp2.h, gse->res);
 #endif
