@@ -111,8 +111,7 @@ int searchfontdatabase(char* ffpath, char* ffname,
 
 void cleanfontdatabase(void) {
   fontdesc* font;
-  int c;
-  int i,j;
+  int c,i;
 #ifdef DEBUGFONTDATABASE
   pfprot("(cleanfontdatabase ");
   j=0;
@@ -286,15 +285,14 @@ static long hs[SMAX], vs[SMAX], ws[SMAX], xs[SMAX], ys[SMAX], zs[SMAX];
 static char comment[257], dvicomment[257];
 
 static double conv, vconv, sconv, svconv;
-static long  /*dvimag ,*/a, b, q, w, x, y, z, h, v;
-static long  mag, spl,  mxh, mxv, lastpage;
-static int k;
+static long  a, b, q, w, x, y, z, h, v;
+static long  spl,  mxh, mxv, lastpage;
 static int cfont;
 static ushort s, mst;
 
 void fontdef(long fontnr) { 
   uchar  p, q;
-  int f,fdb,a;
+  int f,fdb;
   long dsz,scf,chksum;
   float fontmag;  
   fontdesc *font;
@@ -391,15 +389,18 @@ int unigetfont(long fontnr, fontdescvect* fvect, int fvectlen) {
   if (fvect[f].fontdataptr != -1) 
     if (fvect[f].dfn == fontnr)
       return(fvect[f].fontdataptr);
-  a = 0;
+  a = 0; atleast=-1;
   do {
-    if (fvect[a].fontdataptr == -1) a++;
+    if(fvect[a].fontdataptr == -1) a++;
       else if (fvect[a].dfn != fontnr) atleast=a++;
         else return(fvect[a].fontdataptr);
   } while (a < fvectlen);
   pfprot("\n %u ->",fontnr);
   dvibad("is not defined as a fontnumber");
-  return(fvect[atleast].fontdataptr);
+  if(atleast!=-1)
+    return(fvect[atleast].fontdataptr);
+  pfprot("\n fatal error: not a single valid font. sorry\n");
+  exit(1);
 }
 
 
@@ -416,11 +417,15 @@ static void pagebeg(pagelistelement* apage) {
   h = 0;
   v = 0;
   htex_beginpage(apage);
+  loadcolorstack(apage); /* assume its read already */
 }
 
-static void pageend(void) {
+static void pageend(pagelistelement* apage) {
   if (s != 0)  pfprot("warning: stack not empty at eop");
   htex_endpage(); 
+  if(apage->num+1<pageanz)  /* save it worth */
+    if(pagelist[apage->num+1].cstackp<0)
+      savecolorstack(pagelist+apage->num+1);
 }
 
 
@@ -485,14 +490,15 @@ static void postamb(void) {
 }
 
 
-static initpagelist(void) {
+static void initpagelist(void) {
   short i;
   uchar o;
 #ifdef DEBUGDVI
-  pfprot("(initpagelist: pagenaz %d ",pageanz);
+  pfprot("(initpagelist: pageanz %d ",pageanz);
 #endif
   allocmem(&pagelist,MAX(1,pageanz)*sizeof(pagelistelement));
   memset(pagelist,0,MAX(1,pageanz)*sizeof(pagelistelement)); /* all lists NULL */
+  for(i=0;i<pageanz;i++) pagelist[i].cstackp=-1;             /* all colorstacks invalid */
   cpage=pagelist;
   if(pageanz==0) {
     dvibad("zero pages ?");
@@ -565,6 +571,7 @@ short gotocccpage(double* ccc, short sp) {
  return(i);
 }
     
+void  readcolorstack(pagelistelement*); /* forward */
 
 
 void initdvi(void) { 
@@ -616,7 +623,6 @@ void initdvi(void) {
 
 void killdvi(void) {
   int i;
-  int c;
 #ifdef DEBUGDVI
   pfprot("(killdvi ...");
 #endif 
@@ -630,8 +636,10 @@ void killdvi(void) {
   }
   freemem(&greytab);
   htex_kill();
-  for(i=0;i<pageanz ; i++)
+  for(i=0;i<pageanz ; i++){
     freelrumem(&(pagelist[i].drawlist));
+    freemem(&(pagelist[i].cstack));
+  }
   freemem(&pagelist);
   pageanz=0;
   cpage=NULL;
@@ -641,7 +649,7 @@ void killdvi(void) {
 }
 
 
-int  runvfmacro(chdesc* thechar);  /* forward */
+void runvfmacro(chdesc* thechar);  /* forward */
 
 static void listchar(int c,fontdesc* font) {
   
@@ -655,6 +663,7 @@ static void listchar(int c,fontdesc* font) {
     q = 0;
     return;
   }
+  /* pfprot("(%c)",c); */
   /*pfprot("(listchar %d ... )",c);*/ 
   /*if(font->encoding)
      fprintf(prot,"%s",font->encoding[c]); */ 
@@ -666,12 +675,16 @@ static void listchar(int c,fontdesc* font) {
     htex_recordbits(h,v,1,1);  
   if(thechar->fty & PKTYPE) {  /* try pk first*/
     /*fprintf(prot," its a pk: c %d fin %d h %d v %d ...)",c,fontintnr,h,v);*/ 
+#ifdef LETSTRYCOLOR
+    if(dimmcolor==3) return;
+#endif
     q = thechar->tfw;
     if(fshrink == 1.0) {
       data=drawlistadd(*drawcharbmp);
       (*data).chr.h= LROUND(conv * h);
       (*data).chr.v= LROUND(vconv * v);
       (*data).chr.chdp=thechar; 
+      (*data).chr.c=dimmcolor; 
       return;
     }
     if(colors == BLACKNWHITE || fshrink < 1.0) { 
@@ -679,6 +692,7 @@ static void listchar(int c,fontdesc* font) {
       (*data).chr.h= LROUND(sconv * h);
       (*data).chr.v= LROUND(svconv * v);
       (*data).chr.chdp=thechar; 
+      (*data).chr.c=dimmcolor; 
       return;
     } 
     /*if shrinked and greyed { ... */
@@ -687,6 +701,7 @@ static void listchar(int c,fontdesc* font) {
     (*data).chr.h= LROUND(sconv * h);
     (*data).chr.v= LROUND(svconv * v);
     (*data).chr.chdp=thechar; 
+    (*data).chr.c=dimmcolor; 
     return;
   } /* end pk */
   if (thechar->fty & VFTYPE) {                            /* try vf */
@@ -696,7 +711,6 @@ static void listchar(int c,fontdesc* font) {
        return;
     }
     /* Debugging code: draw at least something */
-    /*
     /*br = LROUND(sconv * (thechar->tfw));
     hr = LROUND(sconv * h);
     vr = LROUND(svconv *v);
@@ -763,6 +777,7 @@ static void listspecial(void) {
   dvibytes(specstr,spl);
   if(checkndoHyperTeX(specstr,h,v)) return;
   if(checkndoEpsFile(specstr,h,v,sconv,svconv)) return;
+  if(checkndoColor(specstr)) return;
   /* insert other specials here */
   specstr[MIN(MAXSPECIALPROT,MAXSPECIAL)]=0;
   if(spl<=MAXSPECIALPROT)
@@ -786,6 +801,9 @@ static void listrule(void) {
  
   /*fprintf(prot,
        "(listrule: le %5.1f bo %5.1f wi %5.1f hi %5.1f) ",le,bo,wi,hi);*/ 
+#ifdef LETSTRYCOLOR
+  if(dimmcolor==3) return; /* dimmned completely */
+#endif
   if(fshrink == 1.0) {        /* do it like they told me ... not shrunken*/  
     wi=LCEIL(wi); hi=LCEIL(hi);
     data=drawlistadd(*drawruleor);
@@ -793,7 +811,7 @@ static void listrule(void) {
     (*data).rect.y=bo-hi+1;
     (*data).rect.w=wi;
     (*data).rect.h=hi;
-    (*data).rect.c=BLACKCOL;
+    (*data).rect.c= vgadimm(BLACKCOL,dimmcolor);
     return;
   }   
   if(colors==BLACKNWHITE) {                     /* shrunken, blacknwhite*/
@@ -804,7 +822,7 @@ static void listrule(void) {
     (*data).rect.y=bo-hi+1;
     (*data).rect.w=wi;
     (*data).rect.h=hi;
-    (*data).rect.c=BLACKCOL;
+    (*data).rect.c=vgadimm(BLACKCOL,dimmcolor);
     return;
   }                                                    /* is greyscaled*/
   data=drawlistadd(*drawruleor);
@@ -812,7 +830,7 @@ static void listrule(void) {
   (*data).rect.y=bo-LFLOOR(hi)+1;
   (*data).rect.w=LFLOOR(wi);
   (*data).rect.h=LFLOOR(hi);
-  (*data).rect.c=BLACKCOL;
+  (*data).rect.c=vgadimm(BLACKCOL,dimmcolor);
   gs=(uchar)(LROUND((COLORS_PER_GREY-1)*(wi-LFLOOR(wi)))); 
   if(wi < 1) gs=MAX(1,gs);
   data=drawlistadd(*drawruleor);
@@ -820,7 +838,7 @@ static void listrule(void) {
   (*data).rect.y=bo-LROUND(hi)+1;
   (*data).rect.w=1;
   (*data).rect.h=LROUND(hi);
-  (*data).rect.c=gs; 
+  (*data).rect.c=vgadimm(gs,dimmcolor); 
   gs=(uchar)(LROUND((COLORS_PER_GREY-1)*(hi-LFLOOR(hi))));  
   if(hi < 1) gs=MAX(1,gs);
   data=drawlistadd(*drawruleor);
@@ -828,7 +846,7 @@ static void listrule(void) {
   (*data).rect.y=bo-LFLOOR(hi);
   (*data).rect.w=LROUND(wi);
   (*data).rect.h=1;
-  (*data).rect.c=gs; 
+  (*data).rect.c=vgadimm(gs,dimmcolor); 
   /*pfprot("did id\n");*/
 }
 
@@ -871,9 +889,8 @@ long macroint(uchar b)  {
 }
 
 
-int  runvfmacro(chdesc* thechar){
+void runvfmacro(chdesc* thechar){
   uchar o,c;
-  int i,ishr;
   ushort d1,d2;
   int vfcfont;
   long f, scf;
@@ -993,11 +1010,12 @@ int  runvfmacro(chdesc* thechar){
 
 void  readpage(pagelistelement* apage){
   uchar o,c;
-  int i,ishr;
   ushort d1,d2;
   long f;
 
   if(apage->drawlist!=NULL) return;
+  readcolorstack(apage); /* make sure, colorstack is in pagelist */
+
   if(!opentestdvi()) {
     dvibad("dvifile changed/disappeared? reload!");
     return;
@@ -1078,7 +1096,7 @@ void  readpage(pagelistelement* apage){
     o = dvibyte();
   } 
   htex_scalebox(sconv,svconv);
-  pageend();
+  pageend(apage);
   pfprot("] ");
   dviclose();
   if(dvierrorflag)   
@@ -1295,12 +1313,12 @@ void searchreaddvi(int *spage, long *spos) {
   dpage=*spage-1;
   startpos=*spos;
 #ifdef DEBUGDVI
-  pfprot("(searchraeddvi spage %d spos %d ...",*spage,*spos);
+  pfprot("(searchreaddvi spage %d spos %d ...",*spage,*spos);
 #endif
   do { /* run through pages */
     dpage++;
     if(dpage != gotoprpage(dpage)) break;
-    sprintf(messtr,"      [%d]",MAX(-9999,MIN(pagelist[dpage].count[0],9999)));
+    sprintf(messtr,"      [%ld]",MAX(-9999,MIN(pagelist[dpage].count[0],9999)));
     if(proceedthis(messtr)) break; 
     dpos=0;
     dviskip(44L); /* counts and 4*/
@@ -1480,11 +1498,10 @@ void anchorcharq(int c, fontdesc *font) {
 }
 
 
-readanchors(int page) {
+void readanchors(int page) {
   uchar o,c;
-  int i,j,an;
   ushort d1,d2;
-  long f,startpos;
+  long f;
 
   if(!opentestdvi()) {
     dvibad("dvifile changed/disappeared? reload!");
@@ -1600,7 +1617,7 @@ int  searchhref(char* href, int* spage, int* xpxl, int* ypxl){
     if(an== -1) {
       for(*spage=0;*spage<pageanz;(*spage)++) {
         if(pagelist[*spage].anchorsdone!=DONE) {
-          sprintf(messtr,"      [%d]",
+          sprintf(messtr,"      [%ld]",
             MAX(-9999,MIN(pagelist[*spage].count[0],9999)));
           if(proceedthis(messtr)) break; 
           readanchors(*spage);
@@ -1617,5 +1634,88 @@ int  searchhref(char* href, int* spage, int* xpxl, int* ypxl){
 }
 
 
+/****************************************************************************/
+/* set up colorstack ... slow, but how else should one do ?                 */
+/****************************************************************************/
+
+void readcolorstack(pagelistelement* apage) {
+  uchar o;
+  ushort d1,d2;
+  int page;
+  long spl;
+
+#ifndef LETSTRYCOLOR
+  return();
+#endif
+  if(apage->cstackp>=0) return; 
+  killcolorstack();
+  if(apage->num==0) {
+    savecolorstack(apage);
+    return;
+  }
+  for(page=apage->num;page>=0;page--) /* done up to where? */
+    if(pagelist[page].cstackp>=0) break;
+  if(page>=0)
+    loadcolorstack(pagelist+page);
+  else 
+    page=0;
+  if(!opentestdvi()) {
+    dvibad("dvifile changed/disappeared? reload!");
+    return;
+  }
+  for(;page<apage->num;page++){          /* go through pages */
+    /*pfprot("(read colorstack %d)",page); */
+    if(page != gotoprpage(page)){ 
+      dviclose();
+      return;
+    }
+    dviskip(44L); /* counts and 4*/
+    o = dvibyte(); 
+    while (!dvierrorflag && o != 140) {
+      /* fprintf(prot,"(%d)",o);*/ 
+      switch (o) {
+      case 128:  case 129:  case 130:  case 131: 
+        dvinum(o - 127); break;
+      case 132:  
+        dviint(4);  dviint(4); break;
+      case 133:  case 134:  case 135:  case 136:
+        dvinum(o - 132); break;
+      case 137:  
+        a = dviint(4);  b = dviint(4); break;
+      case 139: dvibad("unexpectet bop"); break;
+      case 143:  case 144:  case 145:  case 146:
+        dviint(o - 142);  break;
+      case 148:  case 149:  case 150:  case 151:
+        dviint(o - 147); break;
+      case 153:  case 154:  case 155:  case 156:
+        dviint(o - 152); break;
+      case 157:  case 158:  case 159:  case 160:
+        dviint(o - 156);  break;
+      case 162:  case 163:  case 164:  case 165:
+        dviint(o - 161);  break;
+      case 167:  case 168:  case 169:  case 170:
+        dviint(o - 166);  break;
+      case 235:  case 236:  case 237:  case 238:
+        dvinum(o - 234);  break;
+      case 239:  case 240:  case 241:  case 242:
+        spl = dvinum(o - 238);
+        if(spl<MAXSPECIAL) {
+          dvibytes(specstr,spl);
+          checkndoColor(specstr);
+        } else
+          dviskip((long)spl); 
+        break;
+      case 243:  case 244:  case 245:  case 246:
+        dvinum(o-242); dviskip(12L); 
+        d1 = dvibyte();  d2 = dvibyte();  dviskip((long)(d1 + d2)); break;
+      default:
+        break;
+      } /* end switch o */
+      o = dvibyte();
+    } /* end a page */
+    savecolorstack(pagelist+page+1);
+  } /* end through pages */
+  dviclose();
+}  
 
 
