@@ -3,8 +3,11 @@
 /* This program may be used without any warranty. It may be modified and */
 /* distributed without any restrictions.                                 */
 
+void dvibad(char*);
 void initfontdatabase(void);
 void killfontdatabase(void);
+int searchfontdatabase(char* , char*, long, long, long);
+int allocfontdesc(char*, char*, long, long, long);
 int  getintnr(long fontnr);
 void initdvi(void);
 void killdvi(void);
