@@ -117,7 +117,7 @@ int pkpackednum(void){
 }
 
 
-setpkname(char* fn, float fm, int delta, char* result) {
+void setpkname(char* fn, float fm, int delta, char* result) {
   char buff[MAXPATHSTR];
   int i,j;
 
@@ -154,13 +154,10 @@ setpkname(char* fn, float fm, int delta, char* result) {
   /*fprintf(prot,"%s)",ffname);*/
 }
 
-
+#ifdef KPATHSEA  /* use kpathsea if wanted */
 int pkfind(char* ffpath,char* fontname,float fontmag,char* fftuto)  {  
-  char ffname[MAXPATHSTR];
-  int delta, foundfile;
+  int foundfile;
   FILE* fofile;
-  
-#ifdef KPATHSEA                            /* use kpathsea if wanted */
   kpse_glyph_file_type font_ret;
   char *kpsename=NULL;
   unsigned dpi;
@@ -177,8 +174,12 @@ int pkfind(char* ffpath,char* fontname,float fontmag,char* fftuto)  {
     else if (!kpse_bitmap_tolerance ((double)font_ret.dpi, (double) dpi))
           pfprot(" - loading at %d ", font_ret.dpi);
     } 
-         
-#else                                             /* use my own subs (slow) */
+
+#else   /* use my own subs (slow) */
+int pkfind(char* ffpath,char* fontname,float fontmag,char* fftuto)  {  
+  char ffname[MAXPATHSTR];
+  int delta, foundfile;
+  FILE* fofile;
 
   setpkname(fontname,fontmag,0,ffname);
   foundfile=msearch(ffpath,ffname,fftuto);
@@ -192,8 +193,7 @@ int pkfind(char* ffpath,char* fontname,float fontmag,char* fftuto)  {
        if(foundfile!=0) break;
      }
   }
-#endif
-
+#endif /* tail of pkfind */
   if(foundfile==0) { 
         pfprot(" - no PKfile "); 
         return(0);
@@ -212,10 +212,10 @@ int pkfind(char* ffpath,char* fontname,float fontmag,char* fftuto)  {
 
 
 int pkdef(char* fftuto,int fdb,long chksum)  {  
-  long a, l, goonaddr, fpwidth, dchksum, needmem;
+  long l, goonaddr, fpwidth, dchksum, needmem;
   unsigned long w,h;  
   uchar b, bb;
-  uchar terminate;  short i, j, c;  
+  uchar terminate;  short i, c;  
   chdesc *achar;
   int mchpk;
   
@@ -228,6 +228,7 @@ int pkdef(char* fftuto,int fdb,long chksum)  {
 #ifdef DEBUGPK
   pfprot(" %s - charakters: ",FD(fdb)->fonam);
 #endif
+  l=fpwidth=w=h=c=0;
   mchpk=-1;
   terminate = 0;
   do {  b = pkn1();
@@ -326,7 +327,6 @@ int pkdef(char* fftuto,int fdb,long chksum)  {
 
 
 void pkloadchar(chdesc *thechar){
-        int      n;
         uchar    theflag;
         char    paint_switch;
         char*   pkfilen;
@@ -359,9 +359,9 @@ void pkloadchar(chdesc *thechar){
         alloc_bitmapbw(&thechar->bmp);
         cp = thechar->bmp.bits;
 
-       
         bytes_wide = thechar->bmp.bmu_wide * BYTES_PER_BMUNIT;
         pkbitpos = -1;
+        word=0;
         if (pkdynf == 14) {     /* get raster by bits */
             /* fprintf(prot,"raster: "); */
             clear_bitmap(&thechar->bmp);
@@ -377,7 +377,7 @@ void pkloadchar(chdesc *thechar){
                         cp++;
                         row_bit_pos = BITS_PER_BMUNIT - 1;
                     }
-                    if (word & (1 << pkbitpos)) *cp |= 1 << row_bit_pos;
+                    if (word & (1 << pkbitpos)) *cp |= ((BMUNIT)1) << row_bit_pos;
                 }
             }
         }
@@ -578,7 +578,7 @@ void pkshrinkcharbw(chdesc* theChar) {
   while(rowsleft) {
     if(rows>rowsleft) rows=rowsleft;
     colsleft=theChar->bmp.w;
-    m=(1 << (BITS_PER_BMUNIT -1));
+    m=(((BMUNIT)1) << (BITS_PER_BMUNIT -1));
     cp=newp;
     cols=initcols;
     while(colsleft){
@@ -586,7 +586,7 @@ void pkshrinkcharbw(chdesc* theChar) {
       if(sample(oldp,theChar->bmp.bmu_wide,theChar->bmp.w-colsleft,
                 cols,rows)>=blevel) *cp|=m;
       if(m==1) {
-        m=(1 << (BITS_PER_BMUNIT -1));
+        m=(((BMUNIT)1) << (BITS_PER_BMUNIT -1));
         ++cp;
       } else m >>=1;
       colsleft-=cols;
@@ -661,7 +661,7 @@ void pkshrinkchargs(chdesc* theChar) {
     while(colsleft){
       if(cols>colsleft) cols=colsleft;
       *cp |= 
-         greytab[(sample(oldp,theChar->bmp.w-colsleft, cols,rows))]  << m; 
+         ((BMUNIT)greytab[(sample(oldp,theChar->bmp.w-colsleft, cols,rows))])  << m; 
       if(m) m-=GREYSCALE;
       else {
         m=BITS_PER_BMUNIT -colors;
@@ -710,7 +710,7 @@ void pkshrinkcharazgs(chdesc* theChar) {
   
   int destbmuw, srcbmuw, j,i;
   int rows,cols,firstcols,firstrows,srcrow,srccol,sam;
-  int mrows,mcols,ishrink;
+  int mrows,mcols;
   BMUNIT m;
   BMUNIT *cp,*destptr,*srcptr;
 
@@ -727,7 +727,6 @@ void pkshrinkcharazgs(chdesc* theChar) {
 
   freelrumem(&(theChar->bmp2.bits));
   touchlrumem(&(theChar->bmp.bits));
-  /* ishrink=CEIL(fshrink); fixed size commented out. see below */
   theChar->shrink=fshrink; 
  
   
@@ -755,8 +754,8 @@ void pkshrinkcharazgs(chdesc* theChar) {
   if(firstrows<=0 || firstcols<=0)   
      pfprot("IMPORTANT DEBUGINFORMATION 
 break with fro %d fco %d
-fshr %f ishr %d hof %d vof %d hof2 %d vof2 %d\n",firstrows,firstcols,
-       fshrink, ishrink,theChar->hof,theChar->vof,theChar->hof2,theChar->vof2);
+fshr %f hof %d vof %d hof2 %d vof2 %d\n",firstrows,firstcols,
+       fshrink,theChar->hof,theChar->vof,theChar->hof2,theChar->vof2);
   
        
   theChar->bmp2.type=GREYSCALE;
@@ -811,9 +810,6 @@ fshr %f ishr %d hof %d vof %d hof2 %d vof2 %d\n",firstrows,firstcols,
         ++cp;
       };
       j++;
-      /*srccol=ROUND(j*fshrink)+theChar->hof; 
-      cols=MIN(ishrink,theChar->bmp.w-srccol); */
-
       srccol+=cols; 
       mcols=ROUND((j+1)*fshrink)-ROUND(j*fshrink);
       cols=MIN(mcols,theChar->bmp.w-srccol); 
@@ -821,13 +817,9 @@ fshr %f ishr %d hof %d vof %d hof2 %d vof2 %d\n",firstrows,firstcols,
     /* pfprot("did row\n");*/
     i--; 
     destptr+=destbmuw; 
-    /* srcrow= (theChar->vof+1)-ROUND(i*fshrink);
-    rows=MIN(ishrink,theChar->bmp.h-srcrow); */
-    
     srcrow+=rows;
     mrows=ROUND(i*fshrink)-ROUND((i-1)*fshrink);
     rows=MIN(mrows,theChar->bmp.h-srcrow); 
-   
     srcptr=theChar->bmp.bits+srcrow*srcbmuw;
   }
 /* #else     that is ifdef GREYINBMU */
@@ -935,11 +927,12 @@ fr %f tw %f bw %f oy %d oh %d iy %d ih %d\n",
 
       fsam=0;
       /* count inner part */
-      if(iw!=0 && ih!=0)
+      if(iw!=0 && ih!=0){
         if(iw==1 && ih==1)
           fsam+=TESTBIT(srcptriy,ix);
         else
           fsam+=sample(srcptriy, ix, iw,ih);
+      }
       /* count top and bottom row */
       if(iy==oy+1 && iw!=0)
         fsam+=topweight*samplerow(srcptroy,ix, iw);
@@ -1078,7 +1071,7 @@ fshr %f hof %d vof %d hof2 %d vof2 %d\n",firstrows,firstcols,
   mrows=MAX(1,ROUND(i*fshrink)-ROUND((i-1)*fshrink));
   while(rows>0) {
           
-    m=(1 << (BITS_PER_BMUNIT -1));  
+    m=(((BMUNIT)1) << (BITS_PER_BMUNIT -1));  
     cp=destptr;
     srccol=0;
     cols=firstcols;
@@ -1139,7 +1132,7 @@ void cheapshrinkgs(bitmap* bmp, bitmap* bmp2){
 
   int rowsleft, colsleft, sum;
   int newbuw, oldbuw, m, rshift, lshift;
-  BMUNIT  *oldp, *newp, *op, *dp, *sp;
+  BMUNIT  *oldp, *newp, *dp, *sp, *op;
   uchar tabgs[GSGREY*GSGREY+1];
 
 #ifdef DEBUGPK
@@ -1174,18 +1167,19 @@ void cheapshrinkgs(bitmap* bmp, bitmap* bmp2){
     lshift=BITS_PER_BMUNIT-GREYSCALE;
     rshift=BITS_PER_BMUNIT-GSGREY;
     while(colsleft){
+      op=sp;
 #if GSGREY==2
-    sum= bit_count[(((*sp)>>rshift) & ((1L<<GSGREY)-1L))] 
-        +bit_count[(((sp[oldbuw])>>rshift) & ((1L<<GSGREY)-1L))];
+      sum= bit_count[(((*op)>>rshift) & ((1L<<GSGREY)-1L))] 
+        +bit_count[(((op[oldbuw])>>rshift) & ((1L<<GSGREY)-1L))];
 #endif
 #if GSGREY==4
-    sum=bit_count[((*(op=sp)>>rshift)&((1L<<GSGREY)-1L))] 
-       +bit_count[((*(op+=oldbuw)>>rshift) & ((1L<<GSGREY)-1L))] 
-       +bit_count[((*(op+=oldbuw)>>rshift) & ((1L<<GSGREY)-1L))] 
-       +bit_count[((*(op+=oldbuw)>>rshift) & ((1L<<GSGREY)-1L))];
+      sum=bit_count[((*(op)>>rshift)&((1L<<GSGREY)-1L))] 
+        +bit_count[((*(op+=oldbuw)>>rshift) & ((1L<<GSGREY)-1L))] 
+        +bit_count[((*(op+=oldbuw)>>rshift) & ((1L<<GSGREY)-1L))] 
+        +bit_count[((*(op+=oldbuw)>>rshift) & ((1L<<GSGREY)-1L))];
 #endif
 /*pfprot("%d:%d*",sum,tabgs[sum]);*/
-      *dp |= (tabgs[sum]  << lshift); 
+      *dp |= (((BMUNIT)tabgs[sum])  << lshift); 
       if(lshift) lshift-=GREYSCALE;
       else {
         lshift=BITS_PER_BMUNIT-GREYSCALE;
