@@ -6,7 +6,7 @@
 
 int vffind(char*, char*, char*);
 int vfdef(char*,int,long,long);
-int vflookuppk(int);
+void vflookuppk(int);
 
 
 
