@@ -316,7 +316,7 @@ void allocmem(void* ap,long anz) {
   MEM(ap)=res; 
 }
 
-reallocmem(void *ap, long anz) { 
+void reallocmem(void *ap, long anz) { 
   char* res;
 #ifdef DEBUGMEM
   pfprot("(mem: realloc 0x%x %d)",MEM(ap),anz);
@@ -372,7 +372,6 @@ char *stralloccpy(char** dest, char* src)
 #ifndef DOSFILES
 
 int checkapath(char* prepath,char* path) {
-  char nprepath[MAXPATHSTR], npath[MAXPATHSTR];
   int i,sep,pn,ppn;
 
   /* fprintf(prot,"\n chkapath %s =?= %s \n",prepath,path); */
@@ -412,6 +411,8 @@ int checkapath(char* prepath,char* path) {
       return(checkapath(prepath,path+i));
     return(0);
   }
+  pfprot("(checkapath: never reach this end!)");
+  return(1);
 }
 
 
@@ -464,11 +465,10 @@ int chkrshis(char* result,char* prepath, char* name) {
 }
 
 int rsearch(char* done,char* path,int dep) {
-  char ndone[MAXPATHSTR], npath[MAXPATHSTR];
   FILE* testfile;
   DIR *thisdir, *testdir;
   struct dirent *thisentry;
-  int i,dn,sep,ndep,links;
+  int i,dn,sep;
   struct stat stats;
   
   /* set sep to the position of next "//" in path or -1 if no such */
@@ -512,7 +512,7 @@ int rsearch(char* done,char* path,int dep) {
       if(rsearch(done,path+1,dep))  return(1);
       done[dn]=0;
       if ((thisdir=opendir(done))==NULL) return(0);
-      while(thisentry=readdir(thisdir))
+      while((thisentry=readdir(thisdir)))
         if(    (strcmp(thisentry->d_name,".") != 0)
            && (strcmp(thisentry->d_name,"..") != 0)
            && (strlen(thisentry->d_name)+dn+2 < MAXPATHSTR) ){   
@@ -538,7 +538,6 @@ int msearch(char* mpath,char* filename,char* result) {
   int mpnpo, pnpo,hopo, found;
   char pn[MAXPATHSTR];
   char* homedir;
-  char ch;
  
   homedir = getenv("HOME");
   if(homedir == NULL) homedir="/home_not_def";
@@ -577,7 +576,6 @@ int msearch(char* mpath,char* filename,char* result) {
 
 int completefile(char* total, int which) {
   char npath[MAXPATHSTR], name[MAXPATHSTR];
-  FILE* testfile;
   DIR *thisdir, *testdir;
   struct dirent *thisentry;
   int plen,nlen,tlen;
@@ -620,7 +618,7 @@ int completefile(char* total, int which) {
   
   if((thisdir=opendir(npath))==NULL) return(0);
   found=0;
-  while(thisentry=readdir(thisdir))
+  while((thisentry=readdir(thisdir)))
     if(    (strncmp(thisentry->d_name,name,nlen) ==0)
         && (strlen(thisentry->d_name)+plen+2 < MAXPATHSTR) ){ 
       found++;   
@@ -648,25 +646,23 @@ int completefile(char* total, int which) {
 }
 
 void setworkdir(void) {
-  char* buptr;
-  
-  /* correct version: linux or gnu-c resp. ... */
-#ifdef GNU_GETCWD
-  workdir=getcwd(NULL, 0);
-  if(workdir==NULL) {pfprot("\nfatal error: memory .. getcwd ??\n");exit(1);}
-#else  
+#ifndef GNU_GETCWD
   /* dirty hack, since getcwd is not allways gnu-c ... */
+  char* buptr;
   allocmem(&buptr,2048);
   buptr=getcwd(buptr, 2047);
   buptr[2047]=0;  /*Bug removed by Richard Vosse, Thanks!*/
   workdir=NULL;
   stralloccpy(&workdir, buptr);
   freemem(&buptr);
+#else
+  /* correct version: linux or gnu-c resp. ... */
+  workdir=getcwd(NULL, 0);
+  if(workdir==NULL) {pfprot("\nfatal error: memory .. getcwd ??\n");exit(1);} 
 #endif  
 }
 
 int dvistandard(char** dst,char* src) {  /* may be src==filename */
-  uchar o;
   char rbu[4];
   FILE* file;
   char s[MAXPATHSTR+1];
@@ -711,14 +707,18 @@ int dvistandard(char** dst,char* src) {  /* may be src==filename */
   for(i=0;i<slen-3;){
     lastsep=0;
     for(i=0;i<slen-3;i++) {
-      if(ss[i]==DIRSEPCHAR && ss[i+1]!='.') lastsep=i;  
-      if(ss[i]!=DIRSEPCHAR) continue;
-      if(ss[i+1]!='.')        continue;
-      if(ss[i+2]!='.')        continue;
-      if(ss[i+3]!=DIRSEPCHAR) continue;
-      memmove(ss+lastsep+1,ss+i+4,slen-i-3);
-      slen=strlen(ss);
-      break;
+      if(    ss[i]==DIRSEPCHAR 
+          && ss[i+1]=='.' 
+          && ss[i+2]=='.' 
+          && ss[i+3]==DIRSEPCHAR){
+        memmove(ss+lastsep+1,ss+i+4,slen-i-3);
+        slen=strlen(ss);
+        i = lastsep;
+        break;
+      } else {
+        if(ss[i]==DIRSEPCHAR) 
+          lastsep=i; 
+      }
     }
   }
 #ifdef DEBUGFILE
@@ -877,14 +877,18 @@ int dvistandard(char** dst,char* src) {  /* may be src==filename */
   for(i=0;i<slen-3;){
     lastsep=0;
     for(i=0;i<slen-3;i++) {
-      if(ss[i]==DIRSEPCHAR && ss[i+1]!='.') lastsep=i;  
-      if(ss[i]!=DIRSEPCHAR) continue;
-      if(ss[i+1]!='.')        continue;
-      if(ss[i+2]!='.')        continue;
-      if(ss[i+3]!=DIRSEPCHAR) continue;
-      memmove(ss+lastsep+1,ss+i+4,slen-i-3);
-      slen=strlen(ss);
-      break;
+      if(    ss[i]==DIRSEPCHAR 
+          && ss[i+1]=='.' 
+          && ss[i+2]=='.' 
+          && ss[i+3]==DIRSEPCHAR){
+        memmove(ss+lastsep+1,ss+i+4,slen-i-3);
+        slen=strlen(ss);
+        i = lastsep;
+        break;
+      } else {
+        if(ss[i]==DIRSEPCHAR) 
+          lastsep=i;
+      }
     }
   }
 #ifdef DEBUGFILE
