@@ -81,7 +81,7 @@ int numberargadd(char ch) {
     if(ch=='.' || (ch>='0' && ch<='9')) { 
        numberargstr[numberargstrlen++]=ch;
        if(ch=='.') numberargmode=NAFRAC;
-       numberargmode=NAINTE;
+       else numberargmode=NAINTE;
        return(0);
     } 
     return(1);
@@ -116,6 +116,8 @@ int numberargadd(char ch) {
     return(1);
   default:
   }
+  pfprot("(numberargadd: parsing error)");
+  return(1);    
 }
 
 int numberargsub(int count) {
@@ -127,6 +129,7 @@ int numberargsub(int count) {
   numberarginit();
   for(count=0;count<newlen;count++) 
      numberargadd(argsave[count]);
+  return(0);
 }
 
 int numberargread(void) {
@@ -220,11 +223,10 @@ void stringarginit(void) {
 
 int stringargedit(int line,int pos,char* defa) {
   uchar o;
-  int len,i;
+  int len=0,i;
   int allesfrisch=1;
   int hispos;
   char editstr[MAXARGSTR+1];
-  char comstr[MAXPATHSTR+1];
  
   freemem(stringarghis+STRARGHIS-1);
   for(i=STRARGHIS-1;i>0;i--) stringarghis[i]=stringarghis[i-1];
@@ -296,7 +298,7 @@ int stringargedit(int line,int pos,char* defa) {
 
 int fileargedit(int line,int pos) {
   uchar o;
-  int len,i;
+  int len=0;
   int allesfrisch=1;
   char editstr[MAXPATHSTR+1];
   char comstr[MAXPATHSTR+1];
@@ -371,8 +373,6 @@ int fileargedit(int line,int pos) {
 /****************************************************************************/
  
 int shorthelp(const char* desrc, const char* argdescr, const char* argdef) {
-  /* uchar o; */
-  int result;
   vgasetstatuslines(3);
   drawsl(desrc,0,0,vgastatuslen);
   drawsl("ARGUMENTS: ",1,0,vgastatuslen);
@@ -510,58 +510,68 @@ void help(void) {
 /* do a checkboxes menue  ***************************************************/
 /****************************************************************************/
 
-/* a checkboxstring is e.g. "ZOOMING:  FAST  ARBITRARY "
-/* 1. string must not start with ' ' */
-/* 2. there must be at least two ' ' between options */
-/* 3. string must end with an extra ' ' */
+/* a checkboxstring is e.g. "ZOOMING:  FAST  ARBITRARY " */
+/* 1. string must not start with ' '                     */
+/* 2. there must be at least two ' ' between options     */
+/* 3. string must end with an extra ' '                  */
+/* ... or alternative use dots "COLOR: BLACK ========= WHITE   */
 
 /* where are the brackets? */ 
 int cboxwhere(char* str){
-  int ret=-1;
-  int val=0;
-  while(*str!=0 && ret==-1){
-    if(*str==' ') {
-      while(*str==' ') str++;
-      if(*str!= '[') val++;
-      else ret=val;
-    }
+  int vald=0;
+  int vals=0;
+  while(*str!=0){
+    while(*str!=' ' && *str!='=' && *str!='*' && *str!='['  && *str!=0) str++;
+    if(*str==' ') while(*str==' ') str++;
+    if(*str=='[') return(vals);
+    if(*str=='*') return(vald);
+    if(*str=='=') vald++;
+    vals++;
     str++;
   }
-  return(ret);
+  return(-1);
 }
 
 /* set the brackets */
 int cboxset(char* str, int val){
   char* achar;
-  int pos;
-  for(achar=str; *achar!=0; achar++)
+  int pos,dotmode=0;
+  for(achar=str; *achar!=0; achar++){
     if(*achar=='[' || *achar==']') *achar=' ';
+    if(*achar=='*') *achar='=';
+    if(*achar=='=') dotmode=1;;
+  }
   if(val<0) val=-2;
-  for(achar=str, pos=-1; *achar!=0 && pos!=val; achar++){
-    if(*achar==' ') {
+  for(achar=str, pos=-1; *achar!=0; achar++){
+    if((*achar==' ' && dotmode==0) || (*achar=='=' && dotmode==1)){
       while(*achar==' ') achar++;
       if(*achar!=0) pos++;
-      achar--; /* point on last ' ', gets incremented */
     }
+    if(pos==val) break;
   }
-  if(pos<val) return(0);    /* startover at the left */
+  /* pfprot("<%d %d>",pos,val); */ /* deb */
+  if(pos<val) return(0);    /* startover at the left  */
   if(val<pos) return(pos);  /* startover at the right */
-  *(achar-1)='[';
-  while(*achar!=' ' && *achar!=0) achar++;
-  if(*achar!=0) {
-    *achar=']';
+  if(dotmode) {
+    *achar='*';
     return(pos);
+  } else {
+    *(achar-1)='[';
+    while(*achar!=' ' && *achar!=0) achar++;
+    if(*achar!=0) {
+      *achar=']';
+      return(pos);
+    }
   }
   return(0);
 }
 
 #define CBOXSET(str,val) cboxset(str,cboxset(str,val))
-  
 
-int comdocheckboxes(char** cbmenue, char* title){
-  int val, y, needrefresh;
+/* returns -1 on escape, y else */  
+int comdocheckboxes(char** cbmenue, int y, char* title){
+  int val, needrefresh;
   uchar o;
-  y=0;
   needrefresh=1;
   do{
     if(needrefresh){
@@ -607,7 +617,10 @@ int comdocheckboxes(char** cbmenue, char* title){
     } while(o==KEYNOP);
   } while(o!=KEYESC && o!=KEYRET);
   drawstatusline();
-  return(o==KEYRET);
+  if(o==KEYRET)
+    return(y);
+  else
+    return(-1);
 }
 
 
@@ -699,7 +712,7 @@ void resetsearch(void) {
 /*********** commandprocessing part 1: dont need anything setup,
                                        i.e. cpage, visfmk */
 
-int  setcpage(short pn, float fshr, uchar col, uchar dps, int force){
+int  setcpage(short pn, float fshr, uchar col, uchar dps, int dth, int force){
   int i,ishr;
 #ifdef DEBUGCOM
   pfprot("(setcpage ...");
@@ -728,7 +741,7 @@ int  setcpage(short pn, float fshr, uchar col, uchar dps, int force){
     fshr=MAX(1,LROUND(fshr));
   else
     fshr=(ROUND(100*fshr)/100.0); 
-  if(fshr != fshrink || col != colors || dps!=doeps) {
+  if(fshr != fshrink || col != colors || dps!=doeps || dth != dimmthresh) {
     force=1;
     killgscript();/* this requires killing the drawlists since ...  */
     initgscript();/* ... they might hold pointers to gse. See below */     
@@ -748,6 +761,7 @@ int  setcpage(short pn, float fshr, uchar col, uchar dps, int force){
     fshrink=fshr;
     colors=col;
     doeps=dps;
+    dimmthresh=dth;
   }
   if(cpage->drawlist!=NULL) 
   if(fshr != cpage->fshr || col != cpage->col || dps!=cpage->dps) 
@@ -755,6 +769,7 @@ int  setcpage(short pn, float fshr, uchar col, uchar dps, int force){
   cpage->fshr=fshr;
   cpage->col=col;
   cpage->dps=dps;
+  cpage->dth=dimmthresh;
   cpage->xoffset=0;
   cpage->yoffset=0;
 #ifdef DEBUGCOM
@@ -840,7 +855,7 @@ void comdoposit(int dpn, int dxp, int dyp, float dfs, int force) {
    pfprot("(comdoposit pn %d dxp %d dyp %d fsh %1.2f ...",
        dpn,dxp,dyp,dfs);
 #endif
-  force=setcpage(dpn,dfs,colors,doeps,force); /* take care -- but why */
+  force=setcpage(dpn,dfs,colors,doeps,dimmthresh,force); /* take care -- but why */
   papxpxl=MMTOPXL(visfmk->papxmm); /* required after comdofile         */
   papypxl=MMTOPXL(visfmk->papymm); /* ... makes CATCH & setppage work! */
   dviypos=CATCHYDVI(dyp);          /* myorder: 1. set dviypos          */
@@ -1051,7 +1066,7 @@ void comsetbookmk(int mode){
 
 void comgobackbookmk(int mode) {
   bookmark *thebmk;
-  int i,max,maxi, found,ddf,total;
+  int i,max,maxi,ddf,total;
   char bustr[80], bustr2[MAXPATHSTR+80];
   switch(mode) {
   case COMDO:
@@ -1077,13 +1092,9 @@ void comgobackbookmk(int mode) {
       break;
     }
     updatefilemk();
-    found=0;
     if(backbmks.n>0) {
       thebmk=backbmks.d[0];
       rolldownbookmk(&backbmks);
-      found=1;
-    }
-    if(found) {
       resetsearch();
       ddf=comdofile(thebmk->dvifilename);
       comdoposit(thebmk->pagenum, thebmk->dvixpos,
@@ -1110,7 +1121,7 @@ void comgobackbookmk(int mode) {
 
 
 void comgoprevbookmk(int mode) {
-  bookmark *thebmk, *startbmk;
+  bookmark *thebmk=NULL;
   int name, found,ddf;
   char bustr[80], bustr2[MAXPATHSTR+80];
   switch(mode) {
@@ -1256,7 +1267,7 @@ void comunit(int mode){
 
 int comdoprintpage(int dpg, int gotop) {
   int dodr;
-  dodr=setcpage(dpg,fshrink,colors,doeps,0);
+  dodr=setcpage(dpg,fshrink,colors,doeps,dimmthresh,0);
   if(gotop==1) {
     if(dviypos != MMTOPXL(visfmk->centerymm-visfmk->voffmm)-vgaydim/2) dodr=1;
     if(dvixpos != MMTOPXL(visfmk->centerxmm-visfmk->hoffmm)-vgaxdim/2) dodr=1;
@@ -1302,7 +1313,6 @@ void comprintpage(int mode, int lm){
 
 void comgoto(int mode) {
   short i;
-  char bustr[MAXARGSTR];
   switch(mode) {
   case COMDO:
     if(numberargcount!=0) {
@@ -1368,7 +1378,7 @@ void comdomoveleft(int off) {
 }
 
 void comdomovedown(int off,int over) { 
-  int n,d,p,ro=0;
+  int n,d,ro=0;
   pagelistelement* bpage;
   n=CATCHYDVI(dviypos+off);
   d=n-dviypos;
@@ -1553,11 +1563,12 @@ void commovedown(int mode) {
   case COMDO:
     if(numberargcount==1 && numberarg[0]==PGMAGIC) {
       moveoverpages=1-moveoverpages;
+      comdoposit(cpage->num,dvixpos,dviypos,fshrink,1);
       if(moveoverpages==1)
         ignorethis("MOVE-OVER-PAGES TURNED ON");
       else
         ignorethis("MOVE-OVER-PAGES TURNED OFF"); 
-      comdoposit(cpage->num,dvixpos,dviypos,fshrink,1);
+      /* comdoposit(cpage->num,dvixpos,dviypos,fshrink,1); */
     } else { 
       if(numberargcount==1 && numberarg[0]!=PGMAGIC) 
          SETMOVEOFFDEFPZ(numberarg[0]);
@@ -1585,11 +1596,12 @@ void commoveup(int mode) {
   case COMDO:
     if(numberargcount==1 && numberarg[0]==PGMAGIC) {
       moveoverpages=1-moveoverpages;
+      comdoposit(cpage->num,dvixpos,dviypos,fshrink,1);
       if(moveoverpages==1)
         ignorethis("MOVE-OVER-PAGES TURNED ON");
       else
         ignorethis("MOVE-OVER-PAGES TURNED OFF");
-      comdoposit(cpage->num,dvixpos,dviypos,fshrink,1);
+      /* comdoposit(cpage->num,dvixpos,dviypos,fshrink,1); */
     } else { 
      if(numberargcount==1 && numberarg[0]!=PGMAGIC) 
          SETMOVEOFFDEFPZ(numberarg[0]);
@@ -1694,9 +1706,8 @@ void comfine(int mode, int lm) {
 
 void comdozoom(float newfshrink) {
     float oldshrink;
-    char bustr[80];
     oldshrink=fshrink;
-    if(!setcpage(cpage->num,newfshrink,colors,doeps,0)) return;
+    if(!setcpage(cpage->num,newfshrink,colors,doeps,dimmthresh,0)) return;
     resetsearch();
     papxpxl=MMTOPXL(visfmk->papxmm);
     papypxl=MMTOPXL(visfmk->papymm);
@@ -1737,6 +1748,7 @@ void comzoomfine(int mode, int lm) {
       if(lm== -1) comdozoom(fshrink*zoomfinedef);
       if(lm== +1) comdozoom(fshrink/zoomfinedef);
     }
+    zoomdef=1/fshrink;
     sprintf(bustr,"CURRENT ZOOMFACTOR: %.3f",1.0/fshrink);
     ignorethis(bustr);
     break;
@@ -1965,11 +1977,15 @@ void comrect(int mode) {
     updatelist(); 
     break;
   case COMDEF:
+    rxmm=rectxmm; 
+    rwmm=rectwmm; 
+    rymm=rectymm;  
+    rhmm=rectymm; 
     if(markon) {
-       rxmm=MIN(markdxmm,PXLTOMM(dvixpos+marksxpxl)+visfmk->hoffmm); 
-       rwmm=fabs(markdxmm-PXLTOMM(dvixpos+marksxpxl)-visfmk->hoffmm);
-       rymm=MIN(markdymm,PXLTOMM(dviypos+marksypxl)+visfmk->voffmm);
-       rhmm=fabs(markdymm-PXLTOMM(dviypos+marksypxl)-visfmk->voffmm);
+      rxmm=MIN(markdxmm,PXLTOMM(dvixpos+marksxpxl)+visfmk->hoffmm); 
+      rwmm=fabs(markdxmm-PXLTOMM(dvixpos+marksxpxl)-visfmk->hoffmm);
+      rymm=MIN(markdymm,PXLTOMM(dviypos+marksypxl)+visfmk->voffmm);
+      rhmm=fabs(markdymm-PXLTOMM(dviypos+marksypxl)-visfmk->voffmm);
     }
     sprintf(bustr1,"OFFSET+SIZE (%s) LEFT; TOP; WIDTH; HIGHT",unitnames[theunit]);
     sprintf(bustr2,"%%.%df;%%.%df;%%.%df;%%.%df",
@@ -2033,7 +2049,6 @@ void commark(int mode) {
 }
 
 void comdomarkfollow(void) {
-  int x,y;
   if(markon==0) return;
   drawhideallmarks();
   markdxmm =PXLTOMM(marksxpxl+dvixpos)+visfmk->hoffmm;
@@ -2111,7 +2126,7 @@ void comdohypfollow(void) {
     dviypos=nyp;
     dodr=1;
   }
-  if(setcpage(pn,fshrink,colors,doeps,0)) dodr=1;
+  if(setcpage(pn,fshrink,colors,doeps,dimmthresh,0)) dodr=1;
   if(setppage()) dodr=1; 
   if(dodr) drawupdatepage();
   comdomarks(xpxl-dvixpos,ypxl-dviypos);
@@ -2121,14 +2136,14 @@ void comdohypfollow(void) {
 }
 
 void comdohypnext(void) {
-  char* href;
-  int xpxl, ypxl, pn;
+  int xpxl, ypxl;
   int dodr, nxp,nyp;
   int found;
   
   found=0;
   drawhideallmarks();
   texton=0;
+  nxp=nyp=0;
   if(hypon) {
     xpxl=marksxpxl+dvixpos;
     ypxl=marksypxl+dviypos;
@@ -2148,7 +2163,7 @@ void comdohypnext(void) {
       dviypos=nyp;
       dodr=1;
     }
-    if(setcpage(cpage->num,fshrink,colors,doeps,0)) dodr=1;
+    if(setcpage(cpage->num,fshrink,colors,doeps,dimmthresh,0)) dodr=1;
     if(setppage()) dodr=1; 
     if(dodr) drawupdatepage();
     else    drawshowallmarks();
@@ -2184,10 +2199,10 @@ void comhypnext(int mode) {
 
 
 void comdisp(int mode) {
-  int dispmode;
   float oldshrink,newshrink;
   uchar col, dps, ishr;
-  char* cbdisplayoptions[]={NULL,NULL,NULL,NULL,NULL};
+  int dth,y;
+  char* cbdisplayoptions[]={NULL,NULL,NULL,NULL,NULL,NULL};
   char **cbd;
 
   switch(mode) {
@@ -2196,25 +2211,28 @@ void comdisp(int mode) {
     stralloccpy(cbdisplayoptions+1,"EPS-RENDERING:  ON  OFF ");
     stralloccpy(cbdisplayoptions+2,"GREYSCALES:  ON  OFF ");
     stralloccpy(cbdisplayoptions+3,"ZOOMING:  ARBITRARY  INTEGER ");
-    cbdisplayoptions[4]=NULL;
+    stralloccpy(cbdisplayoptions+4,"COLORS: BLACK ========= WHITE ");
+    cbdisplayoptions[5]=NULL;
     cboxset(cbdisplayoptions[0],2-ppagemode);
     cboxset(cbdisplayoptions[1],doeps==0?1:0);
     cboxset(cbdisplayoptions[2],colors==BLACKNWHITE?1:0);
     cboxset(cbdisplayoptions[3],ishrinkonly==1?1:0);
-    if(comdocheckboxes(cbdisplayoptions,"<O> SET DISPLAY OPTIONS ")){
+    cboxset(cbdisplayoptions[4],dimmthresh);   
+    if((y=comdocheckboxes(cbdisplayoptions,dispos,"<O> SET DISPLAY OPTIONS "))!=-1){
+      dispos=y;
       resetsearch();
       ppagemode= 2-cboxwhere(cbdisplayoptions[0]);
       dps=  cboxwhere(cbdisplayoptions[1])==1? 0:1;
       col=  cboxwhere(cbdisplayoptions[2])==1? BLACKNWHITE:GREYSCALE;
       ishr= cboxwhere(cbdisplayoptions[3])==1? 1:0;
-
+      dth=  cboxwhere(cbdisplayoptions[4]);
       oldshrink=fshrink;
       newshrink=fshrink;
       if(ishr==1 && ishrinkonly==0){
         newshrink=MAX(1,ROUND(fshrink));
       }
       ishrinkonly=ishr;
-      setcpage(cpage->num,newshrink,col,dps,0);
+      setcpage(cpage->num,newshrink,col,dps,dth,0);
       dvixpos=ROUND(oldshrink/ fshrink*(dvixpos+vgaxdim/2)-vgaxdim/2);
       dviypos=ROUND(oldshrink/ fshrink*(dviypos+vgaydim/2)-vgaydim/2);
       papxpxl=MMTOPXL(visfmk->papxmm);
@@ -2237,7 +2255,7 @@ void comdisp(int mode) {
 void comsearch(int mode) {
   int dodr;
   const char* restr;
-  int xpxl,ypxl,nxp,nyp;
+  int nxp,nyp;
   char bustr1[80], bustr2[MAXARGSTR+80];
   switch(mode) {
   case COMDO:
@@ -2265,7 +2283,7 @@ void comsearch(int mode) {
         dviypos=nyp;
         dodr=1;
       }
-      if(setcpage(searchpage,fshrink,colors,doeps,0)) dodr=1;
+      if(setcpage(searchpage,fshrink,colors,doeps,dimmthresh,0)) dodr=1;
       if(setppage()) dodr=1; 
       if(dodr) drawupdatepage();
       if(markon || hypon) {   
@@ -2304,18 +2322,35 @@ void comsearch(int mode) {
 }
 
 
-main(int argc, char **argv) { 
+int main(int argc, char **argv) { 
   uchar o, wasnum, inpanic=0; 
-  int mousex, mousey, mouseleft, mouseright;
   int comode;
   char *parm;
   char *filename=NULL;
-  int i,j,k,ox,oy,ol,or;
-  long f;
+  int i,j,k;
+#ifdef HASMOUSE
+  int mousex, mousey, mouseleft, mouseright;
+  int ox,oy,ol,or;
+#endif
+  pfprot("This is some kind of a DVIewer, %s\n",MYVERSION);
+  pfprot("(C)opyright 1995 Thomas Moor\n\n");
 
+  /* check some arcitecture dependant stuff ... better be configured */ 
+  if(BYTES_PER_BMUNIT !=sizeof(BMUNIT)){
+    pfprot("This message addresses the administrator rather than the user:\n");
+    pfprot("the compiletime option BMLONG64/BMLONG32 seems not to meet your\n");
+    pfprot("machines architecture. Please check the non-i386 section in the\n");
+    pfprot("README and re-compile. Sorry.\n\n");
+    exit(1);
+  }
+  if(sizeof(void*)<sizeof(long)){ /* this is for the lru-buffer in subs.c*/
+    pfprot("This message addresses the administrator rather than the user:\n");
+    pfprot("sizeof \"void*\" is assumed to be at least the size of \"long int\".");
+    pfprot("However, this assumption seems not to be met by your system\n");
+    pfprot("architecture. Sorry.\n\n");
+    exit(1);
+  }
 
-  pfprot( "This is some kind of a DVIewer, %s\n",MYVERSION);
-  pfprot( "(C)opyright 1995 Thomas Moor\n\n");
 
   vgaopen();   /* open a window part 1: get rid of extra privileges if any */
 
@@ -2428,7 +2463,7 @@ main(int argc, char **argv) {
         stralloccpy(&fontformat, parm+2);  break;
       case 't':  case 'T':  
         stralloccpy(&tfmprefix, parm+2);  break;
-      case 'g':  case 'G':  
+      case 'q':  case 'Q':  
         stralloccpy(&vfprefix, parm+2);  break;
       case 'm':  case 'M':  
         sscanf(parm+2, "%ld", &newmag);  break;
@@ -2446,6 +2481,19 @@ main(int argc, char **argv) {
         sscanf(parm+2, "%f,%f,%f,%f", 
           &fmkstar.lrandmm,&fmkstar.rrandmm,
           &fmkstar.orandmm,&fmkstar.urandmm); break;
+      case 'g': /* now, this does not fit in my concept ...*/
+        if(strncasecmp(parm+1,"geometry",8)==0){
+          if(strlen(parm+1)>8) {
+            stralloccpy(&cmlgeometry,parm+9);
+           } else {
+            if(j+1 < argc) {
+               j++; parm = argv[j];
+               stralloccpy(&cmlgeometry,parm);
+	    }
+          }
+        } else         
+          stralloccpy(&cmlgeometry,parm+2);
+        break;
       case '?':  
         pfprot( "use with dvifilename and optional parameters\n");
         pfprot( " -h<horizontal offset>   (default: %5.1f mm)\n", 
@@ -2460,9 +2508,9 @@ main(int argc, char **argv) {
         pfprot( " -f<font directory>      (default: %s)\n", fontprefix);
 	pfprot( " -n<font name format>    (default: %s)\n", fontformat); 
         pfprot( " -t<TFMfile directory>   (default: %s)\n", tfmprefix);
-        pfprot( " -g<VFfile directory>    (default: %s)\n", vfprefix);
+        pfprot( " -q<VFfile directory>    (default: %s)\n", vfprefix);
 #else
-	pfprot( " -f/-n/-t/-g ignored by compiletime option, using kpathsea\n");
+	pfprot( " -f/-n/-t/-q ignored by compiletime option, using kpathsea\n");
 #endif
         pfprot( " -d<diplaywidth>x<height>(default: %dx%d pxl**2)\n",
                                                       vgaxdim,vgaydim);
@@ -2661,10 +2709,18 @@ main(int argc, char **argv) {
       vgasetmouse(vgaxdim/2,vgaydim/2); 
 #else
     if(!(markon || hypon) &&  (mouseleft || mouseright)) {
-      if(mousex<20) ox=mousex+(20-mousex)/10+1;
-      if(mousex>vgaxdim-1-20) ox=mousex-(mousex-(vgaxdim-1-20))/10-1;
-      if(mousey<20) oy=mousey+(20-mousey)/10+1;
-      if(mousey>vgaydim-1-20) oy=mousey-(mousey-(vgaydim-1-20))/10-1;
+      mousex=MAX(MIN(mousex,vgaxdim-1),0);
+      if(mousex<50) ox=mousex+(50-mousex)/5;
+      if(mousex>vgaxdim-1-50) ox=(vgaxdim-1-50)+(mousex-(vgaxdim-1-50))/5;
+      ox=2*mousex-ox;    /* reversve motion in windows systems: more intuitive ? */
+      mousey=MAX(MIN(mousey,vgaydim-1),0);
+      if(mousey<50) oy=mousey+(50-mousey)/5;
+      if(mousey>vgaydim-1-50) oy=(vgaydim-1-50)+(mousey-(vgaydim-1-50))/5;
+      oy=2*mousey-oy;    /* reversve motion in windows systems: more intuitive ? */
+    }
+    if(!(markon || hypon)){ /* reset, for the case we miss an event */
+       if(!mouseleft) ox=mousex;
+       if(!mouseright) oy=mousey;
     }
     if( (markon || hypon) &&  (mouseleft || mouseright)) {
       if(mousex<0) mousex=mousex/10-1;
